addpath ..\UTILITIES ;
addpath ..\DATA ;

% --------------------------------------------------------------------
%  H A R D W I R E D  C A L I B R A T I O N 
%   *** (think twice before modifying) ***
% --------------------------------------------------------------------
delta    = 0.0150;
theta    = 6.0000;
kv_y     = 0.0100;
ceu_ce   = 1-(1-0.79)/0.6;
lsh      = 0.64000;
reprat   = 0.5000;
chi      = 0.5000;
lambdaHP = 1600.00;
Omega    = 0.6000; 
% --------------------------------------------------------------------
%  S A M P L E  M E A N S
% --------------------------------------------------------------------
load estimationData;
sd      = find(date==1983.00);
fd      = find(date==2007.50);
[cstR0,cstY0,cstI0,cstP0,csts0,cstf0,cstW0,cstdf0,cstds0,csts600] = computeMeans(sd,fd);
cstY   = cstY0; 
cstR   = cstR0; 
cstf   = cstf0; 
csts   = csts0; 
cstP   = cstP0; 
cstW   = cstW0; 
cstdf  = cstdf0; 
cstds  = cstds0; 
csts60 = csts600;

sig    =  	 0.7228940853242082900000000; 
ni     =  	 1.9022961237717995000000000; 
hF     =  	 0.6568378881713927700000000; 
nu     =  	 0.5832032155217635700000000; 
alpha  =  	 0.7251680391230420600000000; 
gammap =  	 0.3399799343364851600000000; 
gammaw =  	 0.8208566111080569700000000; 
psin   =  	 1.8616554833816659000000000; 
rhoTR  =  	 0.4573964650908941600000000; 
api    =  	 2.0084853129778297000000000; 
ay     =  	 0.5197738815094051800000000; 

muz0       = cstY/100;
fss0       = cstf/100;
sss0       = csts/100;
Rss0       = cstR/100;
piss0      = cstP/100;
s60ss0     = csts60/100;
mu0        = theta/(theta-1);
s0         = sss0;
f0         = fss0;
u0         = 1;
Delta0     = 1;
pk0        = 1;
pstar0     = 1;
r0         = (1+Rss0)/(1+piss0)-1;
pm0        = 1/mu0;
pia0       = (1+piss0)^4-1;
betaF0     = exp(sig*muz0)*(1+piss0)/(1+Rss0);
MF0        = betaF0/exp(sig*muz0);
rho0       = s0/(1-f0);
phi0       = 1 - (1-(1-rho0)*exp((1-sig)*muz0)*betaF0)*kv_y/rho0 - lsh;
rk0        = ( exp(sig*muz0) - betaF0*(1-delta) )/betaF0;
n0         = f0/(s0+f0);
m0         = rho0*n0;
neu0       = s0*n0;
nuu0       = 1-n0-neu0;
tau0       = (1-n0)/(n0/reprat);
isy0       = (phi0*betaF0*(1-(1-delta)/exp(muz0)))/(( exp(sig*muz0) - betaF0*(1-delta) )/exp(muz0))/(1-Omega);
csy0       = 1-(1-Omega)*isy0-kv_y; 
Num0       = ceu_ce*(1-reprat*(1-n0)/n0)-reprat;
Den0       = ceu_ce + (1+r0)*exp(-muz0)*(1-(1-s0)*ceu_ce);
ae_w0      = Num0/Den0;
psi0       = ((ae_w0*((1+r0)*exp(-muz0)-1)+1)*lsh/(csy0*s60ss0)-1)*0.6/(0.4);
psiRA0     = 0.4*psi0 ;
alpo0      = (0.6-Omega)/0.6*(psiRA0) + (Omega/0.6)*(Omega + (psi0)*(1-Omega));
k0         = exp(muz0)*( mu0*rk0/phi0 )^(1/(phi0-1))*(alpo0)*n0/(1-Omega);
y0         = (1-Omega)*k0*rk0/phi0/exp(muz0);
ym0        = mu0*y0;
i0         = (1-(1-delta)/exp(muz0))*k0;
w0         = lsh*y0/((alpo0)*n0);
bu0        = reprat*w0;
q0         = (1-phi0)*y0/((alpo0)*n0);
Kp0        = mu0*pm0*y0/(1-alpha*exp(muz0)*MF0);
Fp0        = y0/(1-alpha*exp(muz0)*MF0);
v0         = m0^(1/(1-chi))/(1-(1-rho0)*n0)^(chi/(1-chi));
kappav0    = kv_y*y0/v0;
bF_bW0     = s0*(ceu_ce)^(-sig) + (1-s0);
betaW0     = betaF0/bF_bW0;
cuu0       = bu0;
ceu0       = ((1-tau0)*w0-(1-s0-exp(muz0)/(1+r0))*bu0)/(1/ceu_ce - (1-s0-exp(muz0)/(1+r0)) );
ce0        = ceu0/ceu_ce;
ae0        = exp(muz0)/(1+r0)*(ceu0-bu0);
Ae0        = exp(-muz0)*(1-s0)*n0*ae0;
aF0        = -Omega/(1-Omega)*Ae0;
cF0        = (y0 - Omega*( n0*ce0 + (1-f0)*(1-n0)*cuu0 + s0*n0*ceu0 ) - kappav0*v0 - (1-Omega)*i0)/(1-Omega);
lamF0      = ( (1-hF/exp(muz0))*cF0 )^(-sig) ;
lame0      = ( (1-hF/exp(muz0))*ce0 )^(-sig) ;
lameu0     = ( (1-hF/exp(muz0))*ceu0 )^(-sig) ;
MW0        = betaW0*exp(-sig*(muz0))*( (1-s0)*lame0 + s0*lameu0 )/lame0;
lambda0    = m0/v0;
c0         = (1-Omega)*cF0 + Omega*(n0*ce0+nuu0*cuu0+neu0*ceu0) ;
c400       = (1-Omega)*cF0;
c600       = Omega*(n0*ce0+nuu0*cuu0+neu0*ceu0);
lamuu0     = ( (1-hF/exp(muz0))*cuu0 )^(-sig) ;
cndreduc10 = 1 - exp(-sig*(muz0))*betaW0*((1-f0)*lamuu0+f0*lame0)*(1+r0)/lameu0;
cndreduc20 = 1 - exp(-sig*(muz0))*betaW0*((1-f0)*lamuu0+f0*lame0)*(1+r0)/lamuu0;
Je0        = (q0-w0)/(1-(1-rho0)*MF0);
cndw0      = w0-bu0;
linv0      = log((1-Omega)*i0 + kappav0*v0);
lcHtM0     = log(c400 + Omega*w0*n0);
% --------------------------------------------------------------------
%
% Step #2 : assign these local values
%
% --------------------------------------------------------------------
r         = r0;
R         = Rss0;
MF        = MF0;
MW        = MW0;
lamF      = lamF0;
lame      = lame0;
lameu     = lameu0;
cF        = cF0;
ce        = ce0;
ceu       = ceu0;
cuu       = cuu0;
aF        = aF0;
ae        = ae0;
Ae        = Ae0;
lambda    = lambda0;
m         = m0;
v         = v0;
s         = s0;
f         = f0;
n         = n0;
neu       = neu0;
nuu       = nuu0;
rho       = rho0;
k         = k0;
i         = i0;
u         = u0;
y         = y0;
ym        = ym0;
rk        = rk0;
pk        = 1;
w         = w0;
q         = q0;
tau       = tau0;
pm        = pm0;
Kp        = Kp0;
Fp        = Fp0;
pstar     = 1;
Delta     = 1;
c         = c0;
c40       = c400;
c60       = c600;
pi        = piss0;
pia       = pia0;
R_o       = cstR;
dC_o      = cstY;
dI_o      = cstY;
dC40_o    = cstY;
dC60_o    = cstY;
s60       = c600/c0;
sh60_o    = 100*s60;
dY_o      = cstY;
df_o      = cstdf;
ds_o      = cstds;
dP_o      = cstP;
dW_o      = cstW;
f_o       = cstf;
s_o       = csts;
cndreduc1 = cndreduc10;
cndreduc2 = cndreduc20;
cndw      = cndw0;
Je        = Je0;
lc        = log(c0);
li        = log(i0);
ly        = log(y0);
lc60      = log(c600);
lc40      = log(c400);
lw        = log(w0);
linv      = linv0;
lcHtM     = lcHtM0;
Ra        = 4*Rss0;
lamuu     = lamuu0;
