% -------------------------------------------------------------------------
%
%                            W A R N I N G:
%
%                T H I S  F I L E  I S  D I S C A R D E D
%
% -------------------------------------------------------------------------
load restrictedData
% -------------------------------------------------------------------------
%
%         I.  I N F O R M A T I O N  O N  T H E  D A T E S
%
% -------------------------------------------------------------------------
% I.A. Date vector for the full sample
% -------------------------------------------------------------------------
fulldate  = date;
fulldate  = date;
fulls     = find(fulldate==1983.0);
fullf     = find(fulldate==2012.5);
splshocks = fulls:fullf;
% -------------------------------------------------------------------------
% I.B. Date vector for NBER recessions
% -------------------------------------------------------------------------
dd0  = [1990.5 2001.0  2007.75];  % vector of NBER recessions - start
dd1  = [1991.0 2001.75 2009.25];  % vector of NBER recessions - end
wdw  = 12; % Window of total time for the pictures
recessionNames = {'1990Q3','2001Q1','GreatRecession'};
% -------------------------------------------------------------------------
% I.C. Generate strings for dates
% -------------------------------------------------------------------------
quarterIndex = [0 .25 .50 .75];
quarterCell = {'Q1','Q2','Q3','Q4'};
celltick = cell(length(date),1);
for iter=1:length(date)
    yearStr = [num2str(floor(date(iter))),...
        quarterCell{date(iter)-floor(date(iter))==quarterIndex}];
    celltick{iter} = yearStr;
end


% ---------------------------------------------------------------------
%
%           II. R E T R I E V E  I N F O R M% A T I O N
%
% ---------------------------------------------------------------------
% II.A Load estimation results
% ---------------------------------------------------------------------
load fullModelSmoother_results
% ---------------------------------------------------------------------
% II.B Some useful basics
% ---------------------------------------------------------------------
vname = M_.endo_names(oo_.dr.order_var,:);
sname = M_.exo_names;
nobs  = length(splshocks); %options_.nobs;
nvar  = length(oo_.dr.order_var); 
nbs   = M_.exo_nbr;
for ii=1:nvar
    eval([deblank(vname(ii,:)),'_i = ',num2str(ii),';'])
end
% ---------------------------------------------------------------------
% II.C Retrieve matrix of smoothed shocks
% ---------------------------------------------------------------------
shocks    = zeros(nbs,nobs);
for ii=1:size(sname,1)
    eval(['shocks(',num2str(ii),',:)=oo_.SmoothedShocks.',deblank(sname(ii,:)),'(splshocks)'';'])
end
% ---------------------------------------------------------------------
% II.D Retrieve matrix of smoothed variables
% ---------------------------------------------------------------------
z_hist = zeros(nvar,nobs);
for ii=1:size(vname,1)
    eval(['z_hist(',num2str(ii),',:)=oo_.SmoothedVariables.',deblank(vname(ii,:)),'(splshocks)'';'])
end
% ---------------------------------------------------------------------
% II.E Useful pieces of information
% ---------------------------------------------------------------------
nstatic = M_.nstatic;
npred   = M_.npred;
nboth   = M_.nboth;
nfwrd   = M_.nfwrd;
% ---------------------------------------------------------------------
% WARNING: In DR, the variables are ordered as:
% static first, then backward, then mixed, and finally forward
% ---------------------------------------------------------------------
% II.F Extract indices of variables
% ---------------------------------------------------------------------
Ny = [1:nstatic,nstatic+npred+nboth+1:nstatic+npred+nboth+nfwrd];
Ns = (nstatic+1:nstatic+npred+nboth);
% ---------------------------------------------------------------------
% II.G Retrieve matrices of the model's LoM
% ---------------------------------------------------------------------
Ay = oo_.dr.ghx(Ny,:);
As = oo_.dr.ghx(Ns,:);
By = oo_.dr.ghu(Ny,:);
Bs = oo_.dr.ghu(Ns,:);
% ---------------------------------------------------------------------


sname = vname(Ns,:);

idVector = zeros(size(sname,1),2);
for iter=1:size(sname,1)
    idName1 = deblank(sname(iter,:));
    chk1 = ~isempty(strfind(idName1,'_IM'));
    if chk1
        for jter=1:size(sname,1)
            idName2 = deblank(sname(jter,:));
            chk2 = strcmp([idName1(1:strfind(idName1,'_IM')-1),'_HM'],idName2);
            if chk2
                idVector(iter,:) = [iter,jter];
            end
        end
    end
end
idVector = idVector(idVector(:,1)>0,:);

ssvals = oo_.dr.ys(oo_.dr.order_var);


for recessionNumber=3:3
    
    
    dds  = find(date==dd0(recessionNumber));
    ddf  = find(date==dd1(recessionNumber));
    smpl = dds:dds+wdw; 
    hor  = length(smpl);
    
    % Initialize state variables
    sinit  = z_hist(Ns,smpl(1)-1); %
    sinit(idVector(:,2)) = sinit(idVector(:,1));
    %sinit = zeros(size(sinit));
    
    % Preformat matrices
    s   = zeros(npred+nboth,hor);
    y   = zeros(nstatic+nfwrd,hor);
    
    % Simulate the two models at once
    for tt=1:hor
        s_t = As*sinit + Bs*shocks(:,smpl(tt));
        y_t = Ay*sinit + By*shocks(:,smpl(tt));
        sinit = s_t;
        s(:,tt) = s_t;
        y(:,tt) = y_t;
    end
    z = [y(1:nstatic,:) ; s ; y(nstatic+1:nstatic+nfwrd,:)];
    
    trd = cumsum( ssvals(dY_o_i)/100 + z(fiz_i,:) );
    
    lC_IM = z(lc_IM_i,:) + trd;
    lC_HM = z(lc_HM_i,:) + trd;
    lY_IM = z(ly_IM_i,:) + trd;
    lY_HM = z(ly_HM_i,:) + trd;
    lI_IM = z(linv_IM_i,:) + trd;
    lI_HM = z(linv_HM_i,:) + trd;
    S_IM  = z(s_IM_i,:) + ssvals(s_o_i)/100 ;
    S_HM  = z(s_HM_i,:) + ssvals(s_o_i)/100 ;
    F_IM  = z(f_IM_i,:) + ssvals(f_IM_i) ;
    F_HM  = z(f_HM_i,:) + ssvals(f_IM_i) ;
    N_IM  = z(n_IM_i,:) + ssvals(n_IM_i) ;
    N_HM  = z(n_HM_i,:) + ssvals(n_IM_i) ;
    PI_IM = z(pi_IM_i,:) + ssvals(dP_o_i)/100;
    PI_HM = z(pi_HM_i,:) + ssvals(dP_o_i)/100;

    
    xIM = [lC_IM' lI_IM' F_IM' S_IM' N_IM' PI_IM'];
    xHM = [lC_HM' lI_HM' F_HM' S_HM' N_HM' PI_HM'];
    
    titCell = {'Consumption','Investment',...
        'Job-Finding Rate','Job-Loss Rate','Employment Rate','Inflation'};
    labelStrings = {'Proportional deviation from ','Level deviation from '};
    labelTypes = [1 1 2 2 2 2];
    
    figure(recessionNumber)
    % ---------------------------------------------------------------------
    for iter = 1:6
        % -----------------------------------------------------------------
        subplot(3,2,iter)
        lcn1 = 0; %100*xIM(1,iter);
        lcn2 = 0; %100*xIM(1,iter);
        % -----------------------------------------------------------------
        % Dummy graph to get right dimensions
        % -----------------------------------------------------------------
        hp0 = plot(date(smpl),100*xIM(:,iter)-lcn1,...
            date(smpl),100*xHM(:,iter)-lcn2);
        set(hp0(1),'linewidth',2,'color',[.5 0 0])
        set(hp0(2),'linewidth',2,'color',[.4 .4 .4],'linestyle','--')
        %axis tight
        hold on
        % -----------------------------------------------------------------
        % Shaded NBER recession
        % -----------------------------------------------------------------
        ylim = get(gca,'ylim');
        ylim = ylim*1.05;
        fi = fill([date(dds) date(dds) date(ddf) date(ddf)],...
            [ylim(1) ylim(2) ylim(2) ylim(1)],...
            [.8 .8 .8]);
        set(fi,'linestyle','none')
        hold on
        % -----------------------------------------------------------------
        % Final graph
        % -----------------------------------------------------------------
        hp = plot(date(smpl),100*xIM(:,iter)-lcn1,...
            date(smpl),100*xHM(:,iter)-lcn2);
        set(hp(1),'linewidth',2,'color',[.5 0 0])
        set(hp(2),'linewidth',2,'color',[.4 .4 .4],'linestyle','--')
        % -----------------------------------------------------------------
        % Axes properties
        % -----------------------------------------------------------------
        set(gca,'xlim',[date(dds) date(dds+wdw)],'box','off','layer','top')
        set(gca,'box','off','fontname','times','layer','top','ylim',ylim)
        std = find(date==date(dds));
        set(gca,'box','off','fontname','times',...
            'layer','top','ylim',ylim,...
            'Xtick',date(std:4:std+wdw),...
            'XTickLabel',celltick(std:4:std+wdw),'fontsize',8)
        ylb = ylabel({labelStrings{labelTypes(iter)};[char(celltick(dds)),' level']});
        set(ylb,'fontsize',9)
        tit = title(titCell{iter});
        set(tit,'fontsize',12)
        hold off
    end
    lgd = legend('Imperfect Insurance (baseline)',...
        'Full Insurance Counterfactual');
    set(lgd,'Orientation','horizontal',...
    'Position',[0.39543679843826 0.00421064318476718 0.282332845290386 0.0628099173553719]);
    set(lgd,'box','off','fontsize',10)
    
    set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],...
        'PaperPosition',[0.1 0.02158 20.3046 15.2284]);
    
    fn = ['..\..\TEXFILES\FIGURES\counterFactualType3Figure',recessionNames{recessionNumber}];
    print( gcf, '-dpdf', fn )
    
end
