% The only program that we'll consider in the end


% -------------------------------------------------------------------------
%
%         I.  I N F O R M A T I O N  O N  T H E  D A T E S
%
% -------------------------------------------------------------------------
% I.A. Date vector for the full sample
% -------------------------------------------------------------------------
date      = 1983.00:.25:2012.5;
fulldate  = date;
fulls     = find(fulldate==1983.0);
fullf     = find(fulldate==2012.5);
splshocks = fulls:fullf;
% -------------------------------------------------------------------------
% I.B. Date vector for NBER recessions
% -------------------------------------------------------------------------
dd0  = [1990.5 2001.0  2007.75];  % vector of NBER recessions - start
dd1  = [1991.0 2001.75 2009.25];  % vector of NBER recessions - end
wdw  = 12; % Window of total time for the pictures
recessionNames = {'1990Q3','2001Q1','GreatRecession'};
% -------------------------------------------------------------------------
% I.C. Generate strings for dates
% -------------------------------------------------------------------------
quarterIndex = [0 .25 .50 .75];
quarterCell = {'Q1','Q2','Q3','Q4'};
celltick = cell(length(date),1);
for iter=1:length(date)
    yearStr = [num2str(floor(date(iter))),...
        quarterCell{date(iter)-floor(date(iter))==quarterIndex}];
    celltick{iter} = yearStr;
end


% ---------------------------------------------------------------------
%
%           II. R E T R I E V E  I N F O R M% A T I O N
%
% ---------------------------------------------------------------------
% II.A Load estimation results
% ---------------------------------------------------------------------
load fullModelSmoother_results
% ---------------------------------------------------------------------
% II.B Some useful basics
% ---------------------------------------------------------------------
vname  = M_.endo_names(oo_.dr.order_var,:);
shname = M_.exo_names;
nobs   = length(splshocks); %options_.nobs;
nvar   = length(oo_.dr.order_var); 
nbs    = M_.exo_nbr;
for ii=1:nvar
    eval([deblank(vname(ii,:)),'_i = ',num2str(ii),';'])
end
% ---------------------------------------------------------------------
% II.C Retrieve matrix of smoothed shocks
% ---------------------------------------------------------------------
shocks    = zeros(nbs,nobs);
for ii=1:size(shname,1)
    eval(['shocks(',num2str(ii),',:)=oo_.SmoothedShocks.',deblank(shname(ii,:)),'(splshocks)'';'])
end
shocksRef = shocks;
% ---------------------------------------------------------------------
% II.D Retrieve matrix of smoothed variables
% ---------------------------------------------------------------------
z_hist = zeros(nvar,nobs);
for ii=1:size(vname,1)
    eval(['z_hist(',num2str(ii),',:)=oo_.SmoothedVariables.',deblank(vname(ii,:)),'(splshocks)'';'])
end
% ---------------------------------------------------------------------
% II.E Useful pieces of information
% ---------------------------------------------------------------------
nstatic = M_.nstatic;
npred   = M_.npred;
nboth   = M_.nboth;
nfwrd   = M_.nfwrd;
% ---------------------------------------------------------------------
% WARNING: In DR, the variables are ordered as:
% static first, then backward, then mixed, and finally forward
% ---------------------------------------------------------------------
% II.F Extract indices of variables
% ---------------------------------------------------------------------
Ny = [1:nstatic,nstatic+npred+nboth+1:nstatic+npred+nboth+nfwrd];
Ns = (nstatic+1:nstatic+npred+nboth);
% ---------------------------------------------------------------------
% II.G Retrieve matrices of the model's LoM
% ---------------------------------------------------------------------
Ay = oo_.dr.ghx(Ny,:);
As = oo_.dr.ghx(Ns,:);
By = oo_.dr.ghu(Ny,:);
Bs = oo_.dr.ghu(Ns,:);
% ---------------------------------------------------------------------



ssvals = oo_.dr.ys(oo_.dr.order_var);
titCell = {'Consumption','Investment',...
    'Job-Finding Rate','Job-Loss Rate','Employment Rate','Inflation'};
labelStrings = {'Proportional deviation from ','Level deviation from '};
labelTypes = [1 1 2 2 2 2];
cntFig = 0;

for recessionNumber=3:3
    
    collIM = zeros(wdw+1,6,nbs-2);
    collHM = zeros(wdw+1,6,nbs-2);
    cntFig = cntFig + 1;
    
    for shockNumber = 1:nbs-2
        
        shocks = zeros(size(shocksRef));
        shocks(shockNumber,:) = shocksRef(shockNumber,:);
        
        dds  = find(date==dd0(recessionNumber));
        ddf  = find(date==dd1(recessionNumber));
        smpl = dds:dds+wdw; %splshocks ;
        hor  = length(smpl);
        
        % Initialize state variables
        sinit  = zeros(length(Ns),1); % No contribution of initial states
        
        % Preformat matrices
        s   = zeros(npred+nboth,hor);
        y   = zeros(nstatic+nfwrd,hor);
        
        % Simulate the two models at once
        for tt=1:hor
            s_t = As*sinit + Bs*shocks(:,smpl(tt));
            y_t = Ay*sinit + By*shocks(:,smpl(tt));
            sinit = s_t;
            s(:,tt) = s_t;
            y(:,tt) = y_t;
        end
        z = [y(1:nstatic,:) ; s ; y(nstatic+1:nstatic+nfwrd,:)];
        
        trd = cumsum( z(fiz_i,:) );
        
        lC_IM = z(lc_IM_i,:) + trd;
        lC_HM = z(lc_HM_i,:) + trd;
        lY_IM = z(ly_IM_i,:) + trd;
        lY_HM = z(ly_HM_i,:) + trd;
        lI_IM = z(linv_IM_i,:) + trd;
        lI_HM = z(linv_HM_i,:) + trd;
        S_IM  = z(s_IM_i,:) + ssvals(s_o_i)/100 ;
        S_HM  = z(s_HM_i,:) + ssvals(s_o_i)/100 ;
        F_IM  = z(f_IM_i,:) + ssvals(f_IM_i) ;
        F_HM  = z(f_HM_i,:) + ssvals(f_IM_i) ;
        N_IM  = z(n_IM_i,:) + ssvals(n_IM_i) ;
        N_HM  = z(n_HM_i,:) + ssvals(n_IM_i) ;
        PI_IM = z(pi_IM_i,:) + ssvals(dP_o_i)/100;
        PI_HM = z(pi_HM_i,:) + ssvals(dP_o_i)/100;
        
        xIM = [lC_IM' lI_IM' F_IM' S_IM' N_IM' PI_IM'];
        xHM = [lC_HM' lI_HM' F_HM' S_HM' N_HM' PI_HM'];
        
        collIM(:,:,shockNumber) = xIM;
        collHM(:,:,shockNumber) = xHM;         
    end    
end

fprintf('\tPct. of variance of difference between Im and HM explained by structural shocks\n')
for ii=1:6
    fprintf('\t%s\n',titCell{ii})
    for jj=1:7
        fprintf('\t%-6s  ',deblank(shname(jj,:)))
    end
    fprintf('\n');
    z = squeeze(collIM(:,ii,:)-collHM(:,ii,:));
    s = 100*z.^2./repmat(sum(z.^2,2),1,nbs-2);
    z = s([1 5 9 13],:);
    for tt=1:4
        for jj=1:7
            fprintf('\t%-2.4f  ',z(tt,jj))
        end
        fprintf('\n');
    end
    fprintf('\n')
end


