load restrictedData
% -------------------------------------------------------------------------
%
%         I.  I N F O R M A T I O N  O N  T H E  D A T E S
%
% -------------------------------------------------------------------------
% I.A. Date vector for the full sample
% -------------------------------------------------------------------------
fulldate  = date;
fulls     = find(fulldate==1983.0);
fullf     = find(fulldate==2012.5);
splshocks = fulls:fullf;
% -------------------------------------------------------------------------
% I.B. Date vector for NBER recessions
% -------------------------------------------------------------------------
dd0  = [1990.5 2001.0  2007.75];  % vector of NBER recessions - start
dd1  = [1991.0 2001.75 2009.25];  % vector of NBER recessions - end
wdw  = 12; % Window of total time for the pictures
recessionNames = {'1990Q3','2001Q1','GreatRecession'};
% -------------------------------------------------------------------------
% I.C. Generate strings for dates
% -------------------------------------------------------------------------
quarterIndex = [0 .25 .50 .75];
quarterCell = {'Q1','Q2','Q3','Q4'};
celltick = cell(length(date),1);
for iter=1:length(date)
    yearStr = [num2str(floor(date(iter))),...
        quarterCell{date(iter)-floor(date(iter))==quarterIndex}];
    celltick{iter} = yearStr;
end


% ---------------------------------------------------------------------
%
%           II. R E T R I E V E  I N F O R M% A T I O N
%
% ---------------------------------------------------------------------
% II.A Load estimation results
% ---------------------------------------------------------------------
load fullModelSmoother_results
% ---------------------------------------------------------------------
% II.B Some useful basics
% ---------------------------------------------------------------------
vname  = M_.endo_names(oo_.dr.order_var,:);
shname = M_.exo_names;
nobs   = length(splshocks); %options_.nobs;
nvar   = length(oo_.dr.order_var); 
nbs    = M_.exo_nbr;
for ii=1:nvar
    eval([deblank(vname(ii,:)),'_i = ',num2str(ii),';'])
end
% ---------------------------------------------------------------------
% II.C Retrieve matrix of smoothed shocks
% ---------------------------------------------------------------------
shocks    = zeros(nbs,nobs);
for ii=1:size(shname,1)
    eval(['shocks(',num2str(ii),',:)=oo_.SmoothedShocks.',deblank(shname(ii,:)),'(splshocks)'';'])
end
shocksRef = shocks;
% ---------------------------------------------------------------------
% II.D Retrieve matrix of smoothed variables
% ---------------------------------------------------------------------
z_hist = zeros(nvar,nobs);
for ii=1:size(vname,1)
    eval(['z_hist(',num2str(ii),',:)=oo_.SmoothedVariables.',deblank(vname(ii,:)),'(splshocks)'';'])
end
% ---------------------------------------------------------------------
% II.E Useful pieces of information
% ---------------------------------------------------------------------
nstatic = M_.nstatic;
npred   = M_.npred;
nboth   = M_.nboth;
nfwrd   = M_.nfwrd;
% ---------------------------------------------------------------------
% WARNING: In DR, the variables are ordered as:
% static first, then backward, then mixed, and finally forward
% ---------------------------------------------------------------------
% II.F Extract indices of variables
% ---------------------------------------------------------------------
Ny = [1:nstatic,nstatic+npred+nboth+1:nstatic+npred+nboth+nfwrd];
Ns = (nstatic+1:nstatic+npred+nboth);
% ---------------------------------------------------------------------
% II.G Retrieve matrices of the model's LoM
% ---------------------------------------------------------------------
Ay = oo_.dr.ghx(Ny,:);
As = oo_.dr.ghx(Ns,:);
By = oo_.dr.ghu(Ny,:);
Bs = oo_.dr.ghu(Ns,:);
% ---------------------------------------------------------------------


sname = vname(Ns,:);

idVector = zeros(size(sname,1),2);
for iter=1:size(sname,1)
    idName1 = deblank(sname(iter,:));
    chk1 = ~isempty(strfind(idName1,'_IM'));
    if chk1
        for jter=1:size(sname,1)
            idName2 = deblank(sname(jter,:));
            chk2 = strcmp([idName1(1:strfind(idName1,'_IM')-1),'_HM'],idName2);
            if chk2
                idVector(iter,:) = [iter,jter];
            end
        end
    end
end
idVector = idVector(idVector(:,1)>0,:);

ssvals = oo_.dr.ys(oo_.dr.order_var);
titCell = {'Consumption','Investment',...
    'Job-Finding Rate','Job-Loss Rate','Employment Rate','Inflation'};
labelStrings = {'Proportional deviation from ','Level deviation from '};
labelTypes = [1 1 2 2 2 2];
cntFig = 0;

for recessionNumber=1:3
    
    cntFig = cntFig + 1;
    
        
        dds  = find(date==dd0(recessionNumber));
        ddf  = find(date==dd1(recessionNumber));
        smpl = dds:dds+wdw; %splshocks ;
        hor  = length(smpl);
        
        % Initialize state variables with zeros
        sinit1  = z_hist(Ns,smpl(1)-1); 
        sinit = sinit1;
        
        % Preformat matrices
        s   = zeros(npred+nboth,hor);
        y   = zeros(nstatic+nfwrd,hor);
        
        % Simulate the two models at once
        for tt=1:hor
            s_t = As*sinit ;
            y_t = Ay*sinit ;
            sinit = s_t;
            s(:,tt) = s_t;
            y(:,tt) = y_t;
        end
        z1 = [y(1:nstatic,:) ; s ; y(nstatic+1:nstatic+nfwrd,:)];
        
        trd = 0;
        lC_IM = z1(lc_IM_i,:) + trd;
        lC_HM = z1(lc_HM_i,:) + trd;
        lI_IM = z1(linv_IM_i,:) + trd;
        lI_HM = z1(linv_HM_i,:) + trd;
        S_IM  = z1(s_IM_i,:); %+ ssvals(s_o_i)/100 ;
        S_HM  = z1(s_HM_i,:); %+ ssvals(s_o_i)/100 ;
        F_IM  = z1(f_IM_i,:); %+ ssvals(f_IM_i) ;
        F_HM  = z1(f_HM_i,:); %+ ssvals(f_IM_i) ;
        N_IM  = z1(n_IM_i,:); %+ ssvals(n_IM_i) ;
        N_HM  = z1(n_HM_i,:); %+ ssvals(n_IM_i) ;
        PI_IM = z1(pi_IM_i,:);% + ssvals(dP_o_i)/100;
        PI_HM = z1(pi_HM_i,:);% + ssvals(dP_o_i)/100;
        
        
        xIM1    = [lC_IM' lI_IM' F_IM' S_IM' N_IM' PI_IM'];
        xHM1    = [lC_HM' lI_HM' F_HM' S_HM' N_HM' PI_HM'];
        collIM1 = xIM1;
        collHM1 = xHM1;
        

        % Initialize state variables with historical states
        sinit2  = z_hist(Ns,smpl(1)-1); %
        sinit2(idVector(:,2)) = sinit2(idVector(:,1));
        sinit = sinit2;
        
        % Preformat matrices
        s   = zeros(npred+nboth,hor);
        y   = zeros(nstatic+nfwrd,hor);
        
        % Simulate the two models at once
        for tt=1:hor
            s_t = As*sinit ;
            y_t = Ay*sinit ;
            sinit = s_t;
            s(:,tt) = s_t;
            y(:,tt) = y_t;
        end
        z2 = [y(1:nstatic,:) ; s ; y(nstatic+1:nstatic+nfwrd,:)];
        
        trd = 0;
        lC_IM = z2(lc_IM_i,:) + trd;
        lC_HM = z2(lc_HM_i,:) + trd;
        lI_IM = z2(linv_IM_i,:) + trd;
        lI_HM = z2(linv_HM_i,:) + trd;
        S_IM  = z2(s_IM_i,:); %+ ssvals(s_o_i)/100 ;
        S_HM  = z2(s_HM_i,:); %+ ssvals(s_o_i)/100 ;
        F_IM  = z2(f_IM_i,:); %+ ssvals(f_IM_i) ;
        F_HM  = z2(f_HM_i,:); %+ ssvals(f_IM_i) ;
        N_IM  = z2(n_IM_i,:); %+ ssvals(n_IM_i) ;
        N_HM  = z2(n_HM_i,:); %+ ssvals(n_IM_i) ;
        PI_IM = z2(pi_IM_i,:);% + ssvals(dP_o_i)/100;
        PI_HM = z2(pi_HM_i,:);% + ssvals(dP_o_i)/100;
        
        
        xIM2    = [lC_IM' lI_IM' F_IM' S_IM' N_IM' PI_IM'];
        xHM2    = [lC_HM' lI_HM' F_HM' S_HM' N_HM' PI_HM'];
        collIM2 = xIM2;
        collHM2 = xHM2;
                
    
    figure(recessionNumber)
    for iter = 1:6
        subplot(3,2,iter)
        hp0 = plot(...
            date(smpl),...
            100*(collHM1(:,iter)-collIM1(:,iter)),...
            date(smpl),...
            100*(collHM2(:,iter)-collIM1(:,iter)));
        set(hp0(1),'linewidth',2,'color',[.5 0 0])
        set(hp0(2),'linewidth',2,'color',[.4 .4 .4])
        if iter==1
            lgd = legend(...
                'HM with initial conditions 1 - IM',...
                'HM with initial conditions 2 - IM');
            set(lgd,'orientation','horizontal')
            set(lgd,'Orientation','horizontal',...
                'Position',...
                [0.334635416666667 0.036710719530101 0.33515625 0.0286343612334802],...
                'box','off');

        end
        % -----------------------------------------------------------------
        % Axes properties
        % -----------------------------------------------------------------
        set(gca,'xlim',[date(dds) date(dds+wdw)],'box','off','layer','top')
        set(gca,'box','off','fontname','times','layer','top','ylim',ylim)
        std = find(date==date(dds));
        set(gca,'box','off','fontname','times',...
            'layer','top','ylim',ylim,...
            'Xtick',date(std:4:std+wdw),...
            'XTickLabel',celltick(std:4:std+wdw),'fontsize',8)
        ylb = ylabel({labelStrings{labelTypes(iter)};'from steady-state level'});
        set(ylb,'fontsize',9)     
        tit = title(titCell{iter});
        set(tit,'fontsize',12)        
    end
    set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],...
        'PaperPosition',[0.1 0.02158 20.3046 15.2284]);
%     fn = ['initialConditionFigure',recessionNames{recessionNumber}];    
%     print( gcf, '-dpdf', fn )

    
end
