% prepareTheData.m:
%
% PURPOSE: Organize the data and save them in a mat file for estimation
% purposes; the mat file is estimationData.mat

addpath ..\UTILITIES

% ___________________________________________________________________
%
%     A.   W A G E  D A T A
% ___________________________________________________________________

% Average weekly earnings from CES - 1964(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data,~] = xlsread('CESweaklyearnings');
wces = data(:,2:13)';
wces = wces(:); % <--- monthly series from 1964(1) to 2012(12)
wces = mean(reshape(wces,3,length(wces)/3))'; % <--- convert to Q freq
clear data

% ___________________________________________________________________
%
%     B.   I N T E R E S T  R A T E  D A T A
% ___________________________________________________________________

% Fed Funds Rate - 1955(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data,~] = xlsread('fedfunds');
ffr = data;
ffr = mean(reshape(ffr,3,length(ffr)/3))'; % <--- convert to Q freq
clear data

% ___________________________________________________________________
%
%     C.   N I P A  D A T A
% ___________________________________________________________________

% NIPA Table 1.1.5 - 1947(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data0,~] = xlsread('table115','Sheet0');
[data1,~] = xlsread('table115','Sheet1');
data = [data0,data1];
ncons = data(5,:)' + data(6,:)';
ninv  = data(4,:)' + data(8,:)' + data(13,:)';
ngov  = data(21,:)';
% ngdp  = (ncons + ngov) + ninv ;
% csy   = (ncons + ngov)./ngdp; % <--- consumption share

ngdp  = ncons + ninv ;
csy   = ncons./ngdp; % <--- consumption share

isy   = ninv./ngdp; % <--- investment share
clear data data0 data1


% NIPA Table 1.1.4 - 1947(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data0,~] = xlsread('table114','Sheet0');
[data1,~] = xlsread('table114','Sheet1');
data = [data0,data1];
pgdp  = data(1,:)'; % <--- GDP deflator
gdp   = ngdp./pgdp ;
clear data data0 data1

% ___________________________________________________________________
%
%     D.   P O P .  A N D  F L O W S  D A T A
% ___________________________________________________________________


% Population - 1948(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data,~] = xlsread('cnp16ov');
pop = data;
pop = mean(reshape(pop,3,length(pop)/3))'; % <--- convert to Q freq
clear data

% Job Market Flows - 1948(Q1) to 2012(Q4)
% -------------------------------------------------------------------
[data,~] = xlsread('JobFlows_170413.xls');
f = data(:,3);
s = data(:,4);
clear data

% ___________________________________________________________________
%
%     E.   C E X  D A T A
% ___________________________________________________________________
load('share');


% ___________________________________________________________________
%
%     F.   O R G A N I Z E  T H E  D A T A
% ___________________________________________________________________

% The shortest sample starts in 1980(Q1) => This calls for rebalancing
% -------------------------------------------------------------------
% First, create vectors of date
% -------------------------------------------------------------------
dateces = 1964:.25:2012.75;
datepcs = 1947:.25:2012.75;
dateffr = 1955:.25:2012.75;
datenip = datepcs;
datepop = 1948:.25:2012.75;
dateflo = 1948:.25:2012.75;
datecex = 1980:.25:2012.50;
% -------------------------------------------------------------------
% Then, define shortest sample
% -------------------------------------------------------------------
sd = 1980.00;
fd = 2012.50;
% -------------------------------------------------------------------
% Select samples
% -------------------------------------------------------------------
smp_ces = find(dateces==sd):find(dateces==fd);
smp_pcs = find(datepcs==sd):find(datepcs==fd);
smp_ffr = find(dateffr==sd):find(dateffr==fd);
smp_nip = smp_pcs;
smp_pop = find(datepop==sd):find(datepop==fd);
smp_flo = find(dateflo==sd):find(dateflo==fd);
smp_cex = find(datecex==sd):find(datecex==fd);
% -------------------------------------------------------------------
% Then rebalance
% -------------------------------------------------------------------
date    = dateces(smp_ces);
wces    = wces(smp_ces);
ffr     = ffr(smp_ffr);
csy     = csy(smp_nip);
isy     = isy(smp_nip);
gdp     = gdp(smp_nip);
pgdp    = pgdp(smp_nip);
pop     = pop(smp_pop);
s       = s(smp_flo);
f       = f(smp_flo);
s_40    = s_40(smp_cex);
s_60    = s_60(smp_cex);
% -------------------------------------------------------------------
% Finally, get the data as needed for estimation
% -------------------------------------------------------------------
dY_o    = 100*diff(log(gdp./pop)); % real per capita gdp growth
dC_o    = 100*diff(log(csy) + log(gdp) - log(pop)); % real cons. growth
sh60_o  = 100*s_60(2:end)'; % cons. share of the 60% poorest
dI_o    = 100*diff(log(isy) + log(gdp) - log(pop)); % real invst. growth
dW_o    = 100*diff(log(wces)); % nominal wage growth
dP_o    = 100*diff(log(pgdp)); % price inflation
R_o     = ffr(2:end)/4; % FF rate converted to quarterly basis
s_o     = 100*s(2:end); % separation rate
f_o     = 100*f(2:end); % job filling rate
z       = s_o - bpass(s_o,2,32);
s_o     = (s_o-z) + mean(s_o);
z       = f_o - bpass(f_o,2,32);
f_o     = (f_o-z) + mean(f_o);
ds_o    = 100*diff(s);  % 1st diff of separation rate
df_o    = 100*diff(f); % 1st diff of job filling rate
date    = date(2:end); % Rebalanced vector of dates

save('estimationData','date','dY_o', 'dC_o', 'sh60_o', 'dI_o', 'dW_o', 'dP_o', ...
     'R_o', 's_o', 'f_o', 'ds_o', 'df_o');
