// SW-like model with precautionary savings, labor market search
//
// Please, refer to the technical appendix for further details
//
// CMRR - Latest version: 05/08/2015
//
// This is the latest try, which almost perfectly works

// --------------------------------------------------------------------
//  S H A R E D  F I L E S
// --------------------------------------------------------------------
addpath ..\UTILITIES ;
addpath ..\DATA ;


// --------------------------------------------------------------------
//  D E F I N E  M O D E L  T Y P E
// --------------------------------------------------------------------
@#define incompleteMarkets = 1
// Takes value 1 if markets are incomplete (Omega = 0.6)
// Takes value 0 if markets are complete (Omega=0.0001)

// --------------------------------------------------------------------
//  D E C L A R A T I O N  B L O C K
// --------------------------------------------------------------------
@#include "..\MODEL\declarationBlock.mod"

// --------------------------------------------------------------------
//  C A L I B R A T I O N  B L O C K
// --------------------------------------------------------------------
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
    rho@{name} = 0;
    sig@{name} = 0;
@#endfor
@#include "..\MODEL\calibrationBlock.mod"


// --------------------------------------------------------------------
//  M O D E L  B L O C K
// --------------------------------------------------------------------
@#include "..\MODEL\modelBlockHM.mod"

// --------------------------------------------------------------------
// P R I O R  B L O C K
// --------------------------------------------------------------------
estimated_params;
sig,     gamma_pdf,      1.5000, 0.200;
ni,      gamma_pdf,      2.0000, 0.200;
hF,      beta_pdf,       0.5000, 0.100;
nu,      beta_pdf,       0.5000, 0.100;

alpha,   beta_pdf,       0.5000, 0.100;
gammap,  beta_pdf,       0.5000, 0.100;
gammaw,  beta_pdf,       0.5000, 0.100;
psin,    gamma_pdf,      1.0000, 0.200;

rhoTR,   beta_pdf,       0.7500, 0.100;
api,     gamma_pdf,      1.5000, 0.100;
ay,      gamma_pdf,      0.1250, 0.100;

rhoz,    beta_pdf,       0.2000, 0.100;
rhoc,    beta_pdf,       0.5000, 0.100;
rhow,    beta_pdf,       0.5000, 0.100;
rhoi,    beta_pdf,       0.5000, 0.100;
rhop,    beta_pdf,       0.5000, 0.100;
rhos,    beta_pdf,       0.5000, 0.100;
rhoR,    beta_pdf,       0.5000, 0.100;
rhome,   beta_pdf,       0.5000, 0.100;

sigc,    inv_gamma_pdf,  1.0000, 0.200;
sigw,    inv_gamma_pdf,  1.0000, 0.200;
sigi,    inv_gamma_pdf,  1.0000, 0.200;
sigp,    inv_gamma_pdf,  1.0000, 0.200;
sigz,    inv_gamma_pdf,  1.0000, 0.200;
sigR,    inv_gamma_pdf,  1.0000, 0.200;
sigs,    inv_gamma_pdf,  1.0000, 0.200;
sigme,   inv_gamma_pdf,  1.0000, 0.200;

end;


// --------------------------------------------------------------------
// E N D  O F  P R I O R  B L O C K
// --------------------------------------------------------------------

varobs dI_o dC_o sh60_o dP_o R_o dW_o s_o f_o;

// --------------------------------------------------------------------
// Numerical initialization to speed up computations
// --------------------------------------------------------------------
  

// --------------------------------------------------------------------
// Estimate model 1985Q1 - 2007Q4
// --------------------------------------------------------------------
estimation(datafile=estimationData,first_obs=12,nobs=99,order=1,
mh_replic=500000,mh_nblocks=2,mh_jscale=0.4,mh_drop=0.25,prior_trunc=0,
bayesian_irf,smoother,plot_priors=0);
// --------------------------------------------------------------------


name = M_.endo_names;
nvar = size(name,1);
for ii=1:nvar
    eval([deblank(name(ii,:)),'_i = ',num2str(ii),';']);
end