% PROGRAM: checkCondition1.m
%
% Full set of observables
%
% Check that three conditions are met at the point estimate
% Condition (1): Validity of the equilibrium reduction (Psi^{uu}, Psi^{eu},
% A^e)
% Condition (2): Value of a match Je > 0
% Condition (3): Real wage higher than unemployment benefits w > b_u
%
% At the beginning of the program, set which point estimate suits you:
% point = 1 => mode ; point = 2 => mean

clear all; close all; clc;

% Vector of dates & point estimate
% -----------------------------------------------------------------------
date  = 1983.00:.25:2007.5;% A modifier ultrieurement


% Load estimation results
% -----------------------------------------------------------------------
load  ..\ESTIMATION\psadImVer4Mcmc_results


% Plots the three conditions
% -----------------------------------------------------------------------
figure(1)
subplot(2,4,1:2)
Y = [oo_.SmoothedVariables.HPDinf.cndreduc1' oo_.SmoothedVariables.HPDsup.cndreduc1'];
arup = area(date,Y(:,2));
set(arup,'facecolor',[.85 .85 .85],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
arlo = area(date,Y(:,1));
set(arlo,'facecolor',[1 1 1],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
hp = plot(date,oo_.SmoothedVariables.Mean.cndreduc1);
set(hp,'linewidth',2,'color',[0 .3 1])
set(gca,'box','off','fontname','times','layer','top')
tit = title('$1-E_X[M^{W}(1,X,X^\prime)(1+r^\prime)] \geq 0$');
set(tit,'interpreter','latex')
hold off


subplot(2,4,3:4)
Y = [oo_.SmoothedVariables.HPDinf.cndreduc2' oo_.SmoothedVariables.HPDsup.cndreduc2'];
arup = area(date,Y(:,2));
set(arup,'facecolor',[.85 .85 .85],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
arlo = area(date,Y(:,1));
set(arlo,'facecolor',[1 1 1],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
hp = plot(date,oo_.SmoothedVariables.Mean.cndreduc2);
set(hp,'linewidth',2,'color',[0 .3 1])
set(gca,'box','off','fontname','times','layer','top')
tit = title('$1-E_X[M^{W}(2,X,X^\prime)(1+r^\prime)] \geq 0$');
set(tit,'interpreter','latex')
hold off


subplot(2,4,6:7)
Y = [oo_.SmoothedVariables.HPDinf.ae' oo_.SmoothedVariables.HPDsup.ae'];
arup = area(date,Y(:,2));
set(arup,'facecolor',[.85 .85 .85],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
arlo = area(date,Y(:,1));
set(arlo,'facecolor',[1 1 1],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)));
hold on
ylim = get(gca,'ylim');
hp = plot(date,oo_.SmoothedVariables.Mean.ae);
set(hp,'linewidth',2,'color',[0 .3 1])
set(gca,'box','off','fontname','times','layer','top') %,'ylim',[.3 .7]
tit = title('$a^{W\prime}(0,X) \geq 0$');
set(tit,'interpreter','latex')

print(gcf,'-dpdf','figuretmp')

set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],'PaperPosition',[0    0.0000   20.4000   15.2500]);
print(gcf,'-dpdf','..\..\TEXFILES\FIGURES\figureEquilibriumReductionCondition1')


figure(2)
subplot(2,1,1)
Y = [oo_.SmoothedVariables.HPDinf.Je' oo_.SmoothedVariables.HPDsup.Je'];
arup = area(date,Y(:,2));
set(arup,'facecolor',[.85 .85 .85],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)))
hold on
arlo = area(date,Y(:,1));
set(arlo,'facecolor',[1 1 1],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)))
hold on
hp = plot(date,oo_.SmoothedVariables.Mean.Je);
set(hp,'linewidth',2,'color',[0 .3 1])
set(gca,'box','off','fontname','times','layer','top')
tit = title('Job Creation Condition  $J^F \geq 0$');
set(tit,'interpreter','latex')

subplot(2,1,2)
Y = [oo_.SmoothedVariables.HPDinf.cndw' oo_.SmoothedVariables.HPDsup.cndw'];
arup = area(date,Y(:,2));
set(arup,'facecolor',[.85 .85 .85],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)))
hold on
arlo = area(date,Y(:,1));
set(arlo,'facecolor',[1 1 1],...
    'edgecolor','k',...
    'linestyle','none',...
    'basevalue',min(Y(:,1)))
hold on
hp = plot(date,oo_.SmoothedVariables.Mean.cndw);
set(hp,'linewidth',2,'color',[0 .3 1])

set(gca,'box','off','fontname','times','layer','top')
tit = title('Wage Rate Condition $w-b_u \geq 0$');
set(tit,'interpreter','latex')

set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],'PaperPosition',[0    0.0000   20.4000   15.2500]);
print(gcf,'-dpdf','..\..\TEXFILES\FIGURES\figureBargainingSet1')
