% PROGRAM: doEstimationTable.m
%
% Program to create a LaTeX table for the estimation results

clear all; close all; clc

PriorNames = { 'Beta' , 'Gamma' , 'Gaussian' , 'Inverted Gamma' ,...
    'Uniform' , 'Inverted Gamma -- 2' };


load ..\ESTIMATION\psadHmVer4Mcmc_results
load ..\ESTIMATION\psadHmVer4Mcmc\prior\definition


% ---------------------------------------------------------------------
%
% P A R T  ( A )  -  P R E P A R E  N A M E S
%
% ---------------------------------------------------------------------

% First retrieve TeX Names in M_
parameterTexNames = M_.param_names_tex;

% Then retrieve internal names in M_
parameterInternalNames = M_.param_names;

% Then retrieve internal names of estimated parameters
estimatedParameterInternalNames = fieldnames(oo_.posterior_mean.parameters);

% Then preformat the TeX names
estimatedParameterTexNames = estimatedParameterInternalNames;

% Then preformat the Prior names
estimatedParameterPriorNames = estimatedParameterInternalNames;

% Then preformat vectors of post. mean & std
estimatedParameterPosteriorMean = zeros(length(estimatedParameterInternalNames),1);
estimatedParameterPosteriorStd = zeros(length(estimatedParameterInternalNames),1);
estimatedParameterPosteriorLo = zeros(length(estimatedParameterInternalNames),1);
estimatedParameterPosteriorHi = zeros(length(estimatedParameterInternalNames),1);

% Then assign TeX names appropriately
for iter = 1:length(estimatedParameterInternalNames)
    S1 = estimatedParameterInternalNames{iter};
    for jter = 1:length(parameterInternalNames)
        S2 = deblank(parameterInternalNames(jter,:));
        TF = strcmp(S1,S2);
        if TF
            estimatedParameterTexNames{iter} = ['$',deblank(parameterTexNames(jter,:)),'$'];
        end
    end
    estimatedParameterPriorNames{iter} = PriorNames{bayestopt_.pshape(iter)};
    estimatedParameterPosteriorMean(iter) = oo_.posterior_mean.parameters.(S1);
    estimatedParameterPosteriorStd(iter) = sqrt(oo_.posterior_variance.parameters.(S1));
    estimatedParameterPosteriorLo(iter) = oo_.posterior_hpdinf.parameters.(S1);
    estimatedParameterPosteriorHi(iter) = oo_.posterior_hpdsup.parameters.(S1);
end

estimatedParameterPriorMean = oo_.prior.mean;
estimatedParameterPriorStd  = sqrt(diag(oo_.prior.variance));


% ---------------------------------------------------------------------
%
% P A R T  ( B )  -  L A T E X  F I L E  F O R  T H E  T A B L E
%
% ---------------------------------------------------------------------

% Now, edit the table in LaTeX syntax
fid = fopen(['..\..\TEXFILES\TABLES\',deblank(M_.fname),'EstimationTableHM1.tex'],'w+');

fprintf(fid,'%s \n','\begin{table}[tbp]');
fprintf(fid,'%s \n','\centering');
fprintf(fid,'%s \n','\caption{Estimation Results - HM Model, Full Set of Observable Variables}\label{tab:esthm1}');
fprintf(fid,'%s \n','\newcolumntype{Y}{>{\centering\arraybackslash}X}');
fprintf(fid,'%s \n','\begin{tabularx}{\textwidth}{llYYYYYY}');
fprintf(fid,'\\hline \\hline \n');
fprintf(fid,'%-15s & %-15s & %-15s & %-15s & %-15s & %-15s & %-15s  & %-15s \\rlo \\rhi \\\\ \n','Parameter','Prior shape','Prior Mean','Prior S.D.',...
    'Post. Mean','Post. S.D.','Low','High');
fprintf(fid,'\\hline \n');
% ---------------------------------------------------------------------
% Automated part of the table
% ---------------------------------------------------------------------
for iter = 1:length(estimatedParameterInternalNames)
    if iter==1
        fprintf(fid,'%-15s & %-15s & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f \\rhi \\\\\n',...
            estimatedParameterTexNames{iter},...
            estimatedParameterPriorNames{iter},...
            estimatedParameterPriorMean(iter),...
            estimatedParameterPriorStd(iter),...
            estimatedParameterPosteriorMean(iter),...
            estimatedParameterPosteriorStd(iter),...
            estimatedParameterPosteriorLo(iter),...
            estimatedParameterPosteriorHi(iter));
    elseif iter==length(estimatedParameterInternalNames)
        fprintf(fid,'%-15s & %-15s & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f \\rlo \\\\\n',...
            estimatedParameterTexNames{iter},...
            estimatedParameterPriorNames{iter},...
            estimatedParameterPriorMean(iter),...
            estimatedParameterPriorStd(iter),...
            estimatedParameterPosteriorMean(iter),...
            estimatedParameterPosteriorStd(iter),...
            estimatedParameterPosteriorLo(iter),...
            estimatedParameterPosteriorHi(iter));
    else
        fprintf(fid,'%-15s & %-15s & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f & %-15.2f \\\\\n',...
            estimatedParameterTexNames{iter},...
            estimatedParameterPriorNames{iter},...
            estimatedParameterPriorMean(iter),...
            estimatedParameterPriorStd(iter),...
            estimatedParameterPosteriorMean(iter),...
            estimatedParameterPosteriorStd(iter),...
            estimatedParameterPosteriorLo(iter),...
            estimatedParameterPosteriorHi(iter));
    end 
end

fprintf(fid,'\\hline \\hline \n');
fprintf(fid,'%s \n','\end{tabularx}');
fprintf(fid,'%s \n','\end{table}');
fclose(fid);