% PROGRAM: doGraphIrfs1.m
%
% Program to create a Bayesian IRFs plot from the baseline point
% estimate
% Monetary Policy shock


clear all; close all; clc


z1 = load('..\ESTIMATION\psadImVer4Mcmc_results');

Hor = 1:20;

shock  = {'epsR'};
vars   = {'Ra','r','pia','ly','lc','linv','n','lw','f'};
labsel = [1 1 1 2 2 2 1 2 1]; 
names  = {'Annualized Nominal Interest Rate',...
    'Quarterly Real Interest Rate',...
    'YoY Inflation Rate',...
    'Output',...
    'Consumption',...
    'Investment',...
    'Employment',...
    'Real Wage',...
    'Job Finding Rate'};

ylb = {'Deviation from s.s.','Relative deviation from s.s.'};

norm1 = z1.oo_.PosteriorIRF.dsge.Mean.Ra_epsR(1);
for jter = 1:length(shock)
    figure(jter)
    for iter = 1:length(vars)
        eval(['x1    = z1.oo_.PosteriorIRF.dsge.Mean.',vars{iter},'_',shock{jter},';'])
        eval(['x1sup = z1.oo_.PosteriorIRF.dsge.HPDsup.',vars{iter},'_',shock{jter},';'])
        eval(['x1inf = z1.oo_.PosteriorIRF.dsge.HPDinf.',vars{iter},'_',shock{jter},';'])
        x1conf = -.25*[x1inf x1sup]/norm1;
        x1     = -.25*x1/norm1;
        x1scale = min(x1conf(:,2));
        x1scale = 1.5*sign(x1scale)*abs(x1scale);
        subplot(3,3,iter)
        area(Hor,x1conf(Hor,1),x1scale,'facecolor',[.85 .85 .85],...
            'edgecolor','k',...
            'linestyle','none')
        hold on
        area(Hor,x1conf(Hor,2),x1scale,'facecolor',[1 1 1],...
            'edgecolor','k',...
            'linestyle','none')
        hold on        
        hp = plot(Hor,x1(Hor)');
        set(hp,'linewidth',2,'color',[0 .3 1],'linestyle','-')
        set(gca,'fontname','times','box','off','layer','top')
        title(names{iter})
        ylabel(ylb{labsel(iter)})
        axis tight
    end
    
    set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],...
        'PaperPosition',[0    0.0000   20.4000   15.2500]);
    print(gcf,'-dpdf',['..\..\TEXFILES\FIGURES\figureIrfs_',shock{jter}])
    
end


