// --------------------------------------------------------------------
//  M O D E L  B L O C K
// --------------------------------------------------------------------
model;
// --------------------------------------------------------------------
//
// A - Preamble
//
// --------------------------------------------------------------------
// A.1 - Parameters not contingent on the value found for psi
// --------------------------------------------------------------------
#nut     = nu/(1-nu);
#muz     = cstY/100;
#fss     = cstf/100;
#sss     = csts/100;
#Rss     = cstR/100;
#piss    = cstP/100;
#s60ss   = csts60/100;
#rss     = (1+Rss)/(1+piss)-1;
#mu      = theta/(theta-1);
#piass   = (1+piss)^4-1;
#betaF   = exp(sig*muz)*(1+piss)/(1+Rss);
#rhoss   = sss/(1-fss);
#rhobar  = log(rhoss/(1-rhoss));
#phi     = 1 - (1-(1-rhoss)*exp((1-sig)*muz)*betaF)*kv_y/rhoss - lsh;
#rkss    = ( exp(sig*muz) - betaF*(1-delta) )/betaF;
#etabar  = rkss;
#nss     = fss/(sss+fss);
#mss     = rhoss*nss;
#isy     = (phi*betaF*(1-(1-delta)/exp(muz)))/(( exp(sig*muz) - betaF*(1-delta) )/exp(muz))/(1-Omega);
#csy     = 1-(1-Omega)*isy-kv_y;
#bF_bW   = sss*(ceu_ce)^(-sig) + (1-sss);
#betaW   = betaF/bF_bW;
#vss     = mss^(1/(1-chi))/(1-(1-rhoss)*nss)^(chi/(1-chi));
#Num     = ceu_ce*(1-reprat*(1-nss)/nss)-reprat;
#Den     = ceu_ce + (1+rss)*exp(-muz)*(1-(1-sss)*ceu_ce);
#ae_w    = Num/Den;
#psi     = ((ae_w*((1+rss)*exp(-muz)-1)+1)*lsh/(csy*s60ss)-1)*0.6/(0.4);
#alpo    = Omega + (psi)*(1-Omega);
#kss     = exp(muz)*( mu*rkss/phi )^(1/(phi-1))*(alpo)*nss/(1-Omega);
#yss     = (1-Omega)*kss*rkss/phi/exp(muz);
#ymss    = mu*yss;
#kappay  = (mu-1)*yss;
#wss     = lsh*yss/((alpo)*nss);
#wbar    = wss*(exp(-muz)/(1+piss))^(gammaw/(gammaw-1));
#bu      = reprat*wss;
#kappav  = kv_y*yss/vss;

// --------------------------------------------------------------------
//
// B - Model Equations
//
// --------------------------------------------------------------------
// B.1 - Common structure
// --------------------------------------------------------------------
@#for name in [ "IM","HM"]

    // Eq. 1: Real interest rate
    1 + r_@{name} = exp(fic)*(1+R_@{name}(-1))/(1+pi_@{name});

    // Eq. 2: Firm owner's SDF
    MF_@{name} = betaF*exp(-sig*(muz+fiz))*lamF_@{name}/lamF_@{name}(-1);

    // Eq. 3: Firm owner's MU of consumption
    lamF_@{name} = (cF_@{name}-hF*cF_@{name}(-1)*exp(-muz - fiz))^(-sig);

    // Eq. 4: Firm owner Euler equation (bonds)
    1 = MF_@{name}(+1)*(1+r_@{name}(+1));

    // Eq. 5: FOC on investment
    1 = pk_@{name}*exp(fii)*(1-.5*ni*(i_@{name}/i_@{name}(-1)*exp(fiz)-1)^2-ni*(i_@{name}/i_@{name}(-1)*exp(fiz)-1)*i_@{name}/i_@{name}(-1)*exp(fiz)) 
        +exp(muz)*MF_@{name}(+1)*pk_@{name}(+1)*exp(fii(+1))*ni*(i_@{name}(+1)/i_@{name}*exp(fiz(+1))-1)*(i_@{name}(+1)/i_@{name}*exp(fiz(+1)))^2;

    // Eq. 6: FOC on u
    rk_@{name} = etabar*(exp(nut*(u_@{name}-1)));

    // Eq. 7: Firm owner Euler equation (capital)
    pk_@{name} = MF_@{name}(+1)*( rk_@{name}(+1)*u_@{name}(+1) - etabar*(exp(nut*(u_@{name}(+1)-1))-1)/nut + (1-delta)*pk_@{name}(+1) );

    // Eq. 8: LoM of capital
    k_@{name} = (1-delta)*k_@{name}(-1)*exp(-muz-fiz) + exp(fii)*( 1 - .5*ni*(i_@{name}*exp(fiz)/i_@{name}(-1)-1)^2 )*i_@{name};

    // Eq. 9: Workers SDF
    MW_@{name} = betaW*exp(-sig*(muz+fiz))*( (1-s_@{name})*lame_@{name} + s_@{name}*lameu_@{name} )/lame_@{name}(-1);

    // Eq. 10: Family members' MU of consumption
    lame_@{name} = (ce_@{name}-hF*ce_@{name}(-1)*exp(-muz - fiz))^(-sig);

    // Eq. 11: MU of consumption for people e->u
    lameu_@{name} = (ceu_@{name}-hF*ceu_@{name}(-1)*exp(-muz - fiz))^(-sig);

    // Eq. 12: Definition of family's wealth
    exp(muz + fiz)*Ae_@{name} = (1-s_@{name})*n_@{name}(-1)*ae_@{name}(-1)+f_@{name}*(1-n_@{name}(-1))*(exp(fia(-1))-1);


    // Eq. 13: Mass of people e->u
    neu_@{name} = s_@{name}*n_@{name}(-1);

    // Eq. 14: Mass of people u->u
    nuu_@{name} = 1 - n_@{name} - neu_@{name};

    // Eq. 15: FOC on price
    pstar_@{name} = Kp_@{name}/Fp_@{name};

    // Eq. 16: Def. of Kp
    Kp_@{name} = mu*exp(fip)*pm_@{name}*y_@{name} 
        + alpha*exp(muz+fiz(+1))*MF_@{name}(+1)*Kp_@{name}(+1)*((1+pi_@{name}(+1))/((1+piss)^(1-gammap)*(1+pi_@{name})^gammap))^theta;

    // Eq. 17: Def. of Fp
    Fp_@{name} = y_@{name} 
        + alpha*exp(muz+fiz(+1))*MF_@{name}(+1)*Fp_@{name}(+1)*((1+pi_@{name}(+1))/((1+piss)^(1-gammap)*(1+pi_@{name})^gammap))^(theta-1);

    // Eq. 18: Aggregate inflation
    1 = (1-alpha)*pstar_@{name}^(1-theta) + alpha*((1+pi_@{name})/((1+piss)^(1-gammap)*(1+pi_@{name}(-1))^gammap))^(theta-1);

    // Eq. 19: Price dispersion
    Delta_@{name} = alpha*( (1+pi_@{name})/((1+piss)^(1-gammap)*(1+pi_@{name}(-1))^gammap) )^(theta)*Delta_@{name}(-1) 
        + (1-alpha)*pstar_@{name}^(-theta) ;

    // Eq. 20: Employment dynamics
    n_@{name} = (1-rho_@{name})*n_@{name}(-1) + lambda_@{name}*v_@{name};

    // Eq. 21: Matches
    m_@{name} = exp(fim)*(1-(1-rho_@{name})*n_@{name}(-1))^chi*v_@{name}^(1-chi);

    // Eq. 22: Separation
    s_@{name} = rho_@{name}*(1-f_@{name});

    // Eq. 23: Job finding rate
    f_@{name} = m_@{name}/(1-(1-rho_@{name})*n_@{name}(-1));

    // Eq. 24: Vacancy filling rate
    lambda_@{name} = m_@{name}/v_@{name};

    // Eq. 25: FOC on vacancies
    kappav/lambda_@{name} = (alpo)*(q_@{name} - w_@{name}) 
        + exp(muz+fiz(+1))*MF_@{name}(+1)*(1-rho_@{name}(+1))*kappav/lambda_@{name}(+1);

    // Eq. 26: Aggregate production
    ym_@{name} = exp(fit)*((1-Omega)*u_@{name}*k_@{name}(-1)*exp(-muz-fiz))^phi*((alpo)*n_@{name})^(1-phi);

    // Eq. 27: Aggregate product
    Delta_@{name}*y_@{name} = ym_@{name} - kappay;

    // Eq. 28: Aggregate resource constraint
    y_@{name}   = (1-Omega)*(cF_@{name} + i_@{name} + (etabar/nut)*(exp(nut*(u_@{name}-1))-1)*k_@{name}(-1)*exp(-muz-fiz))
         + Omega*(n_@{name}*ce_@{name}+nuu_@{name}*cuu_@{name}+neu_@{name}*ceu_@{name}) + kappav*v_@{name} ;

    // Eq. 29: Bond market clearing
    (1-Omega)*aF_@{name} + Omega*Ae_@{name} = 0;

    // Eq. 30: Zero profit of insurance companies
    tau_@{name}*w_@{name}*n_@{name} = bu*(1-n_@{name});

    // Eq. 31: FOC on capital
    rk_@{name} = pm_@{name}*phi*exp(muz+fiz)*ym_@{name}/((1-Omega)*u_@{name}*k_@{name}(-1));

    // Eq. 32: FOC on labor
    q_@{name} = pm_@{name}*(1-phi)*ym_@{name}/((alpo)*n_@{name});

    // Eq. 33: Wage rate
    w_@{name} = (w_@{name}(-1)*exp(-muz-fiz)/(1+pi_@{name}))^gammaw*(wbar*(n_@{name}/nss)^psin)^(1-gammaw)*exp(fiw);

    // Eq. 34: Taylor rule
    log((1+R_@{name})/(1+Rss)) = rhoTR*log((1+R_@{name}(-1))/(1+Rss))
        + (1-rhoTR)*( api*log((1+pi_@{name})/(1+piss)) + ay*(log(y_@{name}/y_@{name}(-1)) + fiz) ) + fiR;

    // Eq. 35: Exogenous separation
    rho_@{name} = 1/(1+exp(-rhobar-fis));

    // Eq. 36: MU of consumption for people u->u
    lamuu_@{name} = (cuu_@{name}-hF*cuu_@{name}(-1)*exp(-muz - fiz))^(-sig);

    // Eq. 37: Condition for Credit Constraint to bind #1
    cndreduc1_@{name} = 1-betaW*exp(-sig*(muz + fiz(+1)))*((1-f_@{name}(+1))*lamuu_@{name}(+1)+f_@{name}(+1)*lame_@{name}(+1))*(1+r_@{name}(+1))/lameu_@{name};

    // Eq. 38: Condition for Credit Constraint to bind #2
    cndreduc2_@{name} = 1-betaW*exp(-sig*(muz + fiz(+1)))*((1-f_@{name}(+1))*lamuu_@{name}(+1)+f_@{name}(+1)*lame_@{name}(+1))*(1+r_@{name}(+1))/lamuu_@{name};

    // Eq. 39: Value of a match
    Je_@{name} = q_@{name} - w_@{name} + (1-rho_@{name}(+1))*MF_@{name}(+1)*Je_@{name}(+1);

    // Eq. 40: w-b_u
    cndw_@{name} = w_@{name}-bu;

    // Eq. 41: Annualized nominal interest rate
    Ra_@{name} = 4*R_@{name};

    // Eq. 42: Aggregate consumption
    c_@{name} = c40_@{name} + c60_@{name} ;

    // Eq. 43: Aggregate consumption
    c60_@{name} = Omega*(n_@{name}*ce_@{name}+nuu_@{name}*cuu_@{name}+neu_@{name}*ceu_@{name}) ;

    // Eq. 44: Aggregate consumption
    c40_@{name} = (1-Omega)*cF_@{name} ;

    // EQ. 45: Share of 60% porest in total consumption
    s60_@{name} = c60_@{name}/c_@{name};

    // EQ. 46: logged consumption
    lc_@{name} = log(c_@{name});

    // EQ. 47: logged investment
    li_@{name} = log(i_@{name});

    // EQ. 48: logged output
    ly_@{name} = log(y_@{name});

    // EQ. 49: logged consumption of 60% poorest
    lc60_@{name} = log(c60_@{name});

    // EQ. 50: logged real wage rate
    lw_@{name} = log(w_@{name});

    // EQ. 51: logged alternative investment
    linv_@{name}   = log((1-Omega)*(i_@{name} + (etabar/nut)*(exp(nut*(u_@{name}-1))-1)*k_@{name}(-1)*exp(-muz-fiz)) + kappav*v_@{name}) ;

    // EQ. 52: logged consumption of 60% poorest
    lc40_@{name} = log(c40_@{name});

@#endfor

// --------------------------------------------------------------------
// B.3 - Eqs. specific to IM
// --------------------------------------------------------------------
// Eq. Spec 1: Workers Euler equation (bonds)
MW_IM(+1)*(1+r_IM(+1)) = 1;

// Eq. Spec 2: Budget constraint of workers' family head
ae_IM + ce_IM = (1-tau_IM)*w_IM + (1+r_IM)*Ae_IM/n_IM ;

// Eq. Spec 3: Consumption of people e->u
ceu_IM = bu + (1+r_IM)*ae_IM(-1)*exp(-muz-fiz)-(exp(fia)-1);


// Eq. Spec 4: Consumption of people u->u
cuu_IM = bu +(1+r_IM)*(exp(fia(-1))-1)*exp(-muz-fiz)- -(exp(fia)-1) ;


// EQ. Spec 5: pseudo-HtM consumption
lcHtM_IM = log(c40_IM + Omega*w_IM*n_IM);

// --------------------------------------------------------------------
// B.4 - Eqs. specific to HM
// --------------------------------------------------------------------
// Eq. Spec 1: Workers Euler equation (bonds)
ae_HM = (exp(fia)-1);

// Eq. Spec 2: Budget constraint of workers' family head
ce_HM + ae_HM = w_HM*n_HM + (1+r_HM)*ae_HM(-1)*exp(-muz - fiz) ;

// Eq. Spec 3: Consumption of people e->u
ceu_HM + ae_HM = w_HM*n_HM + (1+r_HM)*ae_HM(-1)*exp(-muz - fiz) ;

// Eq. Spec 4: Consumption of people u->u
cuu_HM + ae_HM = w_HM*n_HM + (1+r_HM)*ae_HM(-1)*exp(-muz - fiz) ;

// EQ. Spec 5: pseudo-HtM consumption
lcHtM_HM = 0;


// --------------------------------------------------------------------
//
// C - Shocks (common to both versions)
//
// --------------------------------------------------------------------
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
    fi@{name} = rho@{name}*fi@{name}(-1) + (sig@{name}/100)*eps@{name};
@#endfor
// --------------------------------------------------------------------
//
// D - Observables (linked only to IM equations)
//
// --------------------------------------------------------------------

// Eq O1: Observed nominal rate
R_o     = cstR + 100*(R_IM-Rss);

// Eq O2: Observed investment growth
dI_o    = cstY + 100*(linv_IM-linv_IM(-1) + fiz);

// Eq O3: Observed investment growth
dC_o    = cstY + 100*(log(c_IM/c_IM(-1)) + fiz);

// Eq O4: Observed investment growth
sh60_o    = csts60  + 100*(s60_IM - s60ss ) + 100*fime;

// Eq O5: Observed output growth
dY_o    = cstY + 100*(log(y_IM/y_IM(-1)) + fiz);

// Eq O6: Observed inflation rate
dP_o    = cstP + 100*(pi_IM-piss);

// Eq O7: Observed wage inflation rate
dW_o    = cstW + 100*(log(w_IM/w_IM(-1)) + fiz + pi_IM-piss);

// Eq O8: Observed job filling rate
f_o     = cstf + 100*(f_IM-fss);

// Eq O9: Observed separation rate
s_o     = csts + 100*(s_IM-sss);

// Eq O10: Observed job filling rate
df_o   = cstdf + 100*(f_IM-f_IM(-1));

// Eq 11: Observed separation rate
ds_o     = cstds + 100*(s_IM-s_IM(-1));


end;
// --------------------------------------------------------------------
// E N D  O F  M O D E L  B L O C K
// --------------------------------------------------------------------


// --------------------------------------------------------------------
// S T E A D Y  S T A T E  B L O C K
// --------------------------------------------------------------------
//
// Step #1 : define local values
//
// --------------------------------------------------------------------
steady_state_model;
// --------------------------------------------------------------------
// IM Model -> + steady-state restrictions
// --------------------------------------------------------------------
muz0          = cstY/100;
fss0_IM       = cstf/100;
sss0_IM       = csts/100;
Rss0          = cstR/100;
piss0         = cstP/100;
s60ss0_IM     = csts60/100;
mu0           = theta/(theta-1);
s0_IM         = csts/100;
f0_IM         = cstf/100;
u0_IM         = 1;
Delta0_IM     = 1;
pk0_IM        = 1;
pstar0_IM     = 1;
r0_IM         = (1+Rss0)/(1+piss0)-1;
pm0_IM        = 1/mu0;
pia0_IM       = (1+piss0)^4-1;
betaF0        = exp(sig*muz0)*(1+piss0)/(1+Rss0);
MF0_IM        = betaF0/exp(sig*muz0);
rho0          = s0_IM/(1-f0_IM);
phi0          = 1 - (1-(1-rho0)*exp((1-sig)*muz0)*betaF0)*kv_y/rho0 - lsh;
rk0_IM        = ( exp(sig*muz0) - betaF0*(1-delta) )/betaF0;
n0_IM         = f0_IM/(s0_IM+f0_IM);
m0_IM         = rho0*n0_IM;
neu0_IM       = s0_IM*n0_IM;
nuu0_IM       = 1-n0_IM-neu0_IM;
tau0_IM       = (1-n0_IM)/(n0_IM/reprat);
isy0_IM       = (phi0*betaF0*(1-(1-delta)/exp(muz0)))/(( exp(sig*muz0) - betaF0*(1-delta) )/exp(muz0))/(1-Omega);
csy0_IM       = 1-(1-Omega)*isy0_IM-kv_y; 
v0_IM         = m0_IM^(1/(1-chi))/(1-(1-rho0)*n0_IM)^(chi/(1-chi));
bF_bW0        = s0_IM*(ceu_ce)^(-sig) + (1-s0_IM);
betaW0        = betaF0/bF_bW0;
Num0_IM       = ceu_ce*(1-reprat*(1-n0_IM)/n0_IM)-reprat;
Den0_IM       = ceu_ce + (1+r0_IM)*exp(-muz0)*(1-(1-s0_IM)*ceu_ce);
ae_w0_IM      = Num0_IM/Den0_IM;
psi0          = ((ae_w0_IM*((1+r0_IM)*exp(-muz0)-1)+1)*lsh/(csy0_IM*s60ss0_IM)-1)*0.6/(0.4);
alpo0         = (Omega + (psi0)*(1-Omega));
k0_IM         = exp(muz0)*( mu0*rk0_IM/phi0 )^(1/(phi0-1))*(alpo0)*n0_IM/(1-Omega);
y0_IM         = (1-Omega)*k0_IM*rk0_IM/phi0/exp(muz0);
ym0_IM        = mu0*y0_IM;
i0_IM         = (1-(1-delta)/exp(muz0))*k0_IM;
w0_IM         = lsh*y0_IM/((alpo0)*n0_IM);
bu0           = reprat*w0_IM;
q0_IM         = (1-phi0)*y0_IM/((alpo0)*n0_IM);
Kp0_IM        = mu0*pm0_IM*y0_IM/(1-alpha*exp(muz0)*MF0_IM);
Fp0_IM        = y0_IM/(1-alpha*exp(muz0)*MF0_IM);
kappav0       = kv_y*y0_IM/v0_IM;
cuu0_IM       = bu0;
ceu0_IM       = ((1-tau0_IM)*w0_IM-(1-s0_IM-exp(muz0)/(1+r0_IM))*bu0)/(1/ceu_ce - (1-s0_IM-exp(muz0)/(1+r0_IM)) );
ce0_IM        = ceu0_IM/ceu_ce;
ae0_IM        = exp(muz0)/(1+r0_IM)*(ceu0_IM-bu0);
Ae0_IM        = exp(-muz0)*(1-s0_IM)*n0_IM*ae0_IM;
aF0_IM        = -Omega/(1-Omega)*Ae0_IM;
cF0_IM        = (y0_IM - Omega*( n0_IM*ce0_IM + (1-f0_IM)*(1-n0_IM)*cuu0_IM + s0_IM*n0_IM*ceu0_IM ) - kappav0*v0_IM - (1-Omega)*i0_IM)/(1-Omega);
lamF0_IM      = ( (1-hF/exp(muz0))*cF0_IM )^(-sig) ;
lame0_IM      = ( (1-hF/exp(muz0))*ce0_IM )^(-sig) ;
lameu0_IM     = ( (1-hF/exp(muz0))*ceu0_IM )^(-sig) ;
MW0_IM        = betaW0*exp(-sig*(muz0))*( (1-s0_IM)*lame0_IM + s0_IM*lameu0_IM )/lame0_IM;
lambda0_IM    = m0_IM/v0_IM;
c0_IM         = (1-Omega)*cF0_IM + Omega*(n0_IM*ce0_IM+nuu0_IM*cuu0_IM+neu0_IM*ceu0_IM) ;
c400_IM       = (1-Omega)*cF0_IM;
c600_IM       = Omega*(n0_IM*ce0_IM+nuu0_IM*cuu0_IM+neu0_IM*ceu0_IM);
lamuu0_IM     = ( (1-hF/exp(muz0))*cuu0_IM )^(-sig) ;
cndreduc10_IM = 1 - betaW0*exp(-sig*(muz0))*((1-f0_IM)*lamuu0_IM+f0_IM*lame0_IM)*(1+r0_IM)/lameu0_IM;
cndreduc20_IM = 1 - betaW0*exp(-sig*(muz0))*((1-f0_IM)*lamuu0_IM+f0_IM*lame0_IM)*(1+r0_IM)/lamuu0_IM;
Je0_IM        = (q0_IM-w0_IM)/(1-(1-rho0)*MF0_IM);
cndw0_IM      = w0_IM-bu0;
linv0_IM      = log((1-Omega)*i0_IM + kappav0*v0_IM);
lcHtM0_IM     = log(c400_IM + Omega*w0_IM*n0_IM);
wbar0         = w0_IM*(exp(-muz0)/(1+piss0))^(gammaw/(gammaw-1));
// --------------------------------------------------------------------
// CM Model -> Imposing the parameters obtained above
// --------------------------------------------------------------------
// --------------------------------------------------------------------
// CM Model -> Imposing the parameters obtained above
// --------------------------------------------------------------------
ae0_HM        = 0;
Ae0_HM        = 0;
aF0_HM        = 0;
lcHtM0_HM     = 0;
u0_HM         = 1;
Delta0_HM     = 1;
pk0_HM        = 1;
pstar0_HM     = 1;
r0_HM         = (1+Rss0)/(1+piss0)-1;
pm0_HM        = 1/mu0;
pia0_HM       = (1+piss0)^4-1;
MF0_HM        = betaF0/exp(sig*muz0);
MW0_HM        = betaW0/exp(sig*muz0);
rk0_HM        = ( exp(sig*muz0) - betaF0*(1-delta) )/betaF0;
isy0_HM       = (phi0*betaF0*(1-(1-delta)/exp(muz0)))/(( exp(sig*muz0) - betaF0*(1-delta) )/exp(muz0))/(1-Omega);
csy0_HM       = 1-(1-Omega)*isy0_HM-kv_y; 
w0_HM         = wbar0*(exp(-muz0)/(1+piss0))^(gammaw/(1-gammaw));
YsOk0         = rk0_HM/phi0;
YsAn0         = (mu0*YsOk0^phi0)^(1/(phi0-1));
q0_HM         = (1-phi0)*YsAn0;
lambda0_HM    = (1-(1-rho0)*MF0_HM*exp(muz0))*kappav0/(alpo0*(q0_HM-w0_HM));
NsV0          = lambda0_HM^(1/chi);
f0_HM         = NsV0^(chi-1);
s0_HM         = rho0*(1-f0_HM);
n0_HM         = f0_HM/(s0_HM+f0_HM);
neu0_HM       = s0_HM*n0_HM;
nuu0_HM       = 1-n0_HM-neu0_HM;
tau0_HM       = (1-n0_HM)*bu0/(n0_HM*w0_HM);
cuu0_HM       = w0_HM*n0_HM;
ceu0_HM       = w0_HM*n0_HM;
ce0_HM        = w0_HM*n0_HM;
lame0_HM      = ( (1-hF/exp(muz0))*ce0_HM )^(-sig) ;
lameu0_HM     = ( (1-hF/exp(muz0))*ceu0_HM )^(-sig) ;
lamuu0_HM     = ( (1-hF/exp(muz0))*cuu0_HM )^(-sig) ;
y0_HM         = YsAn0*(alpo0*n0_HM);
ym0_HM        = mu0*y0_HM;
v0_HM         = rho0*n0_HM/lambda0_HM;
m0_HM         = rho0*n0_HM;
k0_HM         = exp(muz0)*( mu0*rk0_HM/phi0 )^(1/(phi0-1))*(alpo0)*n0_HM/(1-Omega);
i0_HM         = (1-(1-delta)/exp(muz0))*k0_HM;
Kp0_HM        = mu0*pm0_HM*y0_HM/(1-alpha*exp(muz0)*MF0_HM);
Fp0_HM        = y0_HM/(1-alpha*exp(muz0)*MF0_HM);
cF0_HM        = (y0_HM - Omega*w0_HM*n0_HM - kappav0*v0_HM - (1-Omega)*i0_HM)/(1-Omega);
lamF0_HM      = ( (1-hF/exp(muz0))*cF0_HM )^(-sig) ;
c0_HM         = (1-Omega)*cF0_HM + Omega*w0_HM*n0_HM ;
c400_HM       = (1-Omega)*cF0_HM;
c600_HM       = Omega*w0_HM*n0_HM;
cndreduc10_HM = 1 - betaW0*exp(-sig*(muz0))*((1-f0_HM)*lamuu0_HM+f0_HM*lame0_HM)*(1+r0_HM)/lameu0_HM;
cndreduc20_HM = 1 - betaW0*exp(-sig*(muz0))*((1-f0_HM)*lamuu0_HM+f0_HM*lame0_HM)*(1+r0_HM)/lamuu0_HM;
Je0_HM        = (q0_HM-w0_HM)/(1-(1-rho0)*MF0_HM);
cndw0_HM      = w0_HM-bu0;
linv0_HM      = log((1-Omega)*i0_HM + kappav0*v0_HM);
// --------------------------------------------------------------------
//
// Step #2 : assign these local values
//
// --------------------------------------------------------------------
@#for name in [ "IM", "HM"]
    r_@{name}         = r0_@{name};
    R_@{name}         = Rss0;
    MF_@{name}        = MF0_@{name};
    MW_@{name}        = MW0_@{name};
    lamF_@{name}      = lamF0_@{name};
    lame_@{name}      = lame0_@{name};
    lameu_@{name}     = lameu0_@{name};
    cF_@{name}        = cF0_@{name};
    ce_@{name}        = ce0_@{name};
    ceu_@{name}       = ceu0_@{name};
    cuu_@{name}       = cuu0_@{name};
    aF_@{name}        = aF0_@{name};
    ae_@{name}        = ae0_@{name};
    Ae_@{name}        = Ae0_@{name};
    lambda_@{name}    = lambda0_@{name};
    m_@{name}         = m0_@{name};
    v_@{name}         = v0_@{name};
    s_@{name}         = s0_@{name};
    f_@{name}         = f0_@{name};
    n_@{name}         = n0_@{name};
    neu_@{name}       = neu0_@{name};
    nuu_@{name}       = nuu0_@{name};
    rho_@{name}       = rho0;
    k_@{name}         = k0_@{name};
    i_@{name}         = i0_@{name};
    u_@{name}         = u0_@{name};
    y_@{name}         = y0_@{name};
    ym_@{name}        = ym0_@{name};
    rk_@{name}        = rk0_@{name};
    pk_@{name}        = 1;
    w_@{name}         = w0_@{name};
    q_@{name}         = q0_@{name};
    tau_@{name}       = tau0_@{name};
    pm_@{name}        = pm0_@{name};
    Kp_@{name}        = Kp0_@{name};
    Fp_@{name}        = Fp0_@{name};
    pstar_@{name}     = 1;
    Delta_@{name}     = 1;
    c_@{name}         = c0_@{name};
    c40_@{name}       = c400_@{name};
    c60_@{name}       = c600_@{name};
    pi_@{name}        = piss0;
    pia_@{name}       = pia0_@{name};
    cndreduc1_@{name} = cndreduc10_@{name};
    cndreduc2_@{name} = cndreduc20_@{name};
    cndw_@{name}      = cndw0_@{name};
    Je_@{name}        = Je0_@{name};
    lc_@{name}        = log(c0_@{name});
    li_@{name}        = log(i0_@{name});
    ly_@{name}        = log(y0_@{name});
    lc60_@{name}      = log(c600_@{name});
    lc40_@{name}      = log(c400_@{name});
    lw_@{name}        = log(w0_@{name});
    linv_@{name}      = linv0_@{name};
    lcHtM_@{name}     = lcHtM0_@{name};
    Ra_@{name}        = 4*Rss0;
    lamuu_@{name}     = lamuu0_@{name};
    s60_@{name}       = c600_@{name}/c0_@{name};
@#endfor
R_o       = cstR;
dC_o      = cstY;
dI_o      = cstY;
dC40_o    = cstY;
dC60_o    = cstY;
sh60_o    = 100*s60_IM;
dY_o      = cstY;
df_o      = cstdf;
ds_o      = cstds;
dP_o      = cstP;
dW_o      = cstW;
f_o       = cstf;
s_o       = csts;

// --------------------------------------------------------------------
// Shocks
// --------------------------------------------------------------------
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
    fi@{name} = 0;
@#endfor
end;
// --------------------------------------------------------------------
// E N D  O F  S T E A D Y  S T A T E  B L O C K
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// WARNING: if you want to check the steady state you can uncomment
// the lines below. Please, re-comment them once you're convinced
// that everything works fine
// --------------------------------------------------------------------
//options_.dynatol.f = 1e-10;
//steady;
//check;
//return;

// --------------------------------------------------------------------
// S H O C K  B L O C K
// --------------------------------------------------------------------
shocks;
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
        var  eps@{name};
        stderr 1;
@#endfor
end;
// --------------------------------------------------------------------
// E N D  O F  S H O C K  B L O C K
// --------------------------------------------------------------------
