// --------------------------------------------------------------------
//  M O D E L  B L O C K
// --------------------------------------------------------------------
model;
// --------------------------------------------------------------------
//
// A - Preamble
//
// --------------------------------------------------------------------
#nut     = nu/(1-nu);
#muz     = cstY/100;
#fss     = cstf/100;
#sss     = csts/100;
#Rss     = cstR/100;
#piss    = cstP/100;
#s60ss   = csts60/100;
#rss     = (1+Rss)/(1+piss)-1;
#mu      = theta/(theta-1);
#piass   = (1+piss)^4-1;
#betaF   = exp(sig*muz)*(1+piss)/(1+Rss);
#rhoss   = sss/(1-fss);
#rhobar  = log(rhoss/(1-rhoss));
#phi     = 1 - (1-(1-rhoss)*exp((1-sig)*muz)*betaF)*kv_y/rhoss - lsh;
#rkss    = ( exp(sig*muz) - betaF*(1-delta) )/betaF;
#etabar  = rkss;
#nss     = fss/(sss+fss);
#mss     = rhoss*nss;
#isy     = (phi*betaF*(1-(1-delta)/exp(muz)))/(( exp(sig*muz) - betaF*(1-delta) )/exp(muz))/(1-Omega);
#csy     = 1-(1-Omega)*isy-kv_y;
#Num     = ceu_ce*(1-reprat*(1-nss)/nss)-reprat;
#Den     = ceu_ce + (1+rss)*exp(-muz)*(1-(1-sss)*ceu_ce);
#ae_w    = Num/Den;
#psi     = ((ae_w*((1+rss)*exp(-muz)-1)+1)*lsh/(csy*s60ss)-1)*0.6/(0.4);
#psiRA   = 0.4*psi ;
#alpo    = Omega + (psi)*(1-Omega);
#kss     = exp(muz)*( mu*rkss/phi )^(1/(phi-1))*(alpo)*nss/(1-Omega);
#yss     = (1-Omega)*kss*rkss/phi/exp(muz);
#ymss    = mu*yss;
#kappay  = (mu-1)*yss;
#wss     = lsh*yss/((alpo)*nss);
#wbar    = wss*(exp(-muz)/(1+piss))^(gammaw/(gammaw-1));
#bu      = reprat*wss;
#vss     = mss^(1/(1-chi))/(1-(1-rhoss)*nss)^(chi/(1-chi));
#kappav  = kv_y*yss/vss;
#bF_bW   = sss*(ceu_ce)^(-sig) + (1-sss);
#betaW   = betaF/bF_bW;

// --------------------------------------------------------------------
//
// B - Model Equations
//
// --------------------------------------------------------------------
// Eq. 1: Real interest rate
1 + r = exp(fic)*(1+R(-1))/(1+pi);

// Eq. 2: Firm owner's SDF
MF = betaF*exp(-sig*(muz+fiz))*lamF/lamF(-1);

// Eq. 3: Firm owner's MU of consumption
lamF = (cF-hF*cF(-1)*exp(-muz - fiz))^(-sig);

// Eq. 4: Firm owner Euler equation (bonds)
1 = MF(+1)*(1+r(+1));

// Eq. 5: FOC on investment
1 = pk*exp(fii)*(1-.5*ni*(i/i(-1)*exp(fiz)-1)^2-ni*(i/i(-1)*exp(fiz)-1)*i/i(-1)*exp(fiz)) 
    +exp(muz)*MF(+1)*pk(+1)*exp(fii(+1))*ni*(i(+1)/i*exp(fiz(+1))-1)*(i(+1)/i*exp(fiz(+1)))^2;

// Eq. 6: FOC on u
rk = etabar*(exp(nut*(u-1)));

// Eq. 7: Firm owner Euler equation (capital)
pk = MF(+1)*( rk(+1)*u(+1) - etabar*(exp(nut*(u(+1)-1))-1)/nut + (1-delta)*pk(+1) );

// Eq. 8: LoM of capital
k = (1-delta)*k(-1)*exp(-muz-fiz) + exp(fii)*( 1 - .5*ni*(i*exp(fiz)/i(-1)-1)^2 )*i;

// Eq. 9: Workers SDF
MW = betaW*exp(-sig*(muz+fiz))*( (1-s)*lame + s*lameu )/lame(-1);

// Eq. 10: Family members' MU of consumption
lame = (ce-hF*ce(-1)*exp(-muz - fiz))^(-sig);

// Eq. 11: MU of consumption for people e->u
lameu = (ceu-hF*ceu(-1)*exp(-muz - fiz))^(-sig);

// Eq. 12: Workers Euler equation (bonds)
MW(+1)*(1+r(+1)) = 1;

// Eq. 13: Budget constraint of workers' family head
ae + ce = (1-tau)*w + (1+r)*Ae/n ;

// Eq. 14: Definition of family's wealth
exp(muz + fiz)*Ae = (1-s)*n(-1)*ae(-1) + f*(1-n(-1))*(exp(fia(-1))-1);

// Eq. 15: Consumption of people e->u
ceu = bu + (1+r)*ae(-1)*exp(-muz-fiz)-(exp(fia)-1);

// Eq. 16: Mass of people e->u
neu = s*n(-1);

// Eq. 17: Consumption of people u->u
cuu = bu +(1+r)*(exp(fia(-1))-1)*exp(-muz - fiz) -(exp(fia)-1) ;

// Eq. 18: Mass of people u->u
nuu = 1 - n - neu;

// Eq. 19: FOC on price
pstar = Kp/Fp;

// Eq. 20: Def. of Kp
Kp = mu*exp(fip)*pm*y + alpha*exp(muz+fiz(+1))*MF(+1)*Kp(+1)*((1+pi(+1))/((1+piss)^(1-gammap)*(1+pi)^gammap))^theta;

// Eq. 21: Def. of Fp
Fp = y + alpha*exp(muz+fiz(+1))*MF(+1)*Fp(+1)*((1+pi(+1))/((1+piss)^(1-gammap)*(1+pi)^gammap))^(theta-1);

// Eq. 22: Aggregate inflation
1 = (1-alpha)*pstar^(1-theta) + alpha*((1+pi)/((1+piss)^(1-gammap)*(1+pi(-1))^gammap))^(theta-1);

// Eq. 23: Price dispersion
Delta = alpha*( (1+pi)/((1+piss)^(1-gammap)*(1+pi(-1))^gammap) )^(theta)*Delta(-1) + (1-alpha)*pstar^(-theta) ;

// Eq. 24: Employment dynamics
n = (1-rho)*n(-1) + lambda*v;

// Eq. 25: Matches
m = exp(fim)*(1-(1-rho)*n(-1))^chi*v^(1-chi);

// Eq. 26: Separation
s = rho*(1-f);

// Eq. 27: Job finding rate
f = m/(1-(1-rho)*n(-1));

// Eq. 28: Vacancy filling rate
lambda = m/v;

// Eq. 29: FOC on vacancies
kappav/lambda = (alpo)*(q - w) + exp(muz+fiz(+1))*MF(+1)*(1-rho(+1))*kappav/lambda(+1);

// Eq. 30: Aggregate production
ym = exp(fit)*((1-Omega)*u*k(-1)*exp(-muz-fiz))^phi*((alpo)*n)^(1-phi);

// Eq. 31: Aggregate product
Delta*y = ym - kappay;

// Eq. 32: Aggregate resource constraint
y   = (1-Omega)*(cF + i + (etabar/nut)*(exp(nut*(u-1))-1)*k(-1)*exp(-muz-fiz)) + Omega*(n*ce+nuu*cuu+neu*ceu) + kappav*v ;

// Eq. 33: Bond market clearing
(1-Omega)*aF + Omega*Ae = 0;

// Eq. 34: Zero profit of insurance companies
tau*w*n = bu*(1-n);

// Eq. 35: FOC on capital
rk = pm*phi*exp(muz+fiz)*ym/((1-Omega)*u*k(-1));

// Eq. 36: FOC on labor
q = pm*(1-phi)*ym/((alpo)*n);

// Eq. 37: Wage rate
w = (w(-1)*exp(-muz-fiz)/(1+pi))^gammaw*(wbar*(n/nss)^psin)^(1-gammaw)*exp(fiw);

// Eq. 38: Taylor rule
log((1+R)/(1+Rss)) = rhoTR*log((1+R(-1))/(1+Rss))
 + (1-rhoTR)*( api*log((1+pi)/(1+piss)) + ay*(log(y/y(-1)) + fiz) ) + fiR;

// Eq. 39: YoY Inflation
pia = (1+pi)*(1+pi(-1))*(1+pi(-2))*(1+pi(-3))-1;

// Eq. 40: Exogenous separation
rho = 1/(1+exp(-rhobar-fis));

// Eq. 41: MU of consumption for people u->u
lamuu = (cuu-hF*cuu(-1)*exp(-muz - fiz))^(-sig);

// Eq. 42: Condition for Credit Constraint to bind #1
cndreduc1 = 1 - exp(-sig*(muz + fiz(+1)))*betaW*( (1-f(+1))*lamuu(+1) + f(+1)*lame(+1) )*(1+r(+1))/lameu ;

// Eq. 43: Condition for Credit Constraint to bind #2
cndreduc2 = 1 - exp(-sig*(muz + fiz(+1)))*betaW*( (1-f(+1))*lamuu(+1) + f(+1)*lame(+1) )*(1+r(+1))/lamuu ;

// Eq. 44: Value of a match
Je = q - w + (1-rho(+1))*MF(+1)*Je(+1);

// Eq. 45: w-b_u
cndw = w-bu;

// Eq. 46: Annualized nominal interest rate
Ra = 4*R;

// ----------------------------------------------------------------------
// Auxialiary variables
// -----------------------------------------------------------------------
// Eq. 47: Aggregate consumption
c = c40 + c60 ;

// Eq. 48: Aggregate consumption
c60 = Omega*(n*ce+nuu*cuu+neu*ceu) ;

// Eq. 49: Aggregate consumption
c40 = (1-Omega)*cF ;

// EQ. 50: Share of 60% porest in total consumption
s60 = c60/c;

// EQ. 51: logged consumption
lc = log(c);

// EQ. 52: logged investment
li = log(i);

// EQ. 53: logged output
ly = log(y);

// EQ. 54: logged consumption of 60% poorest
lc60 = log(c60);

// EQ. 55: logged real wage rate
lw = log(w);

// EQ. 56: logged alternative investment
linv   = log((1-Omega)*(i + (etabar/nut)*(exp(nut*(u-1))-1)*k(-1)*exp(-muz-fiz)) + kappav*v) ;

// EQ. 57: pseudo-HtM consumption
lcHtM = log(c40 + Omega*w*n);

// EQ. 58: logged consumption of 60% poorest
lc40 = log(c40);


// --------------------------------------------------------------------
//
// C - Shocks
//
// --------------------------------------------------------------------
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
    fi@{name} = rho@{name}*fi@{name}(-1) + (sig@{name}/100)*eps@{name};
@#endfor
// --------------------------------------------------------------------
//
// D - Observables
//
// --------------------------------------------------------------------

// Eq O1: Observed nominal rate
R_o     = cstR + 100*(R-Rss);

// Eq O2: Observed investment growth
dI_o    = cstY + 100*(linv-linv(-1) + fiz);

// Eq O2: Observed investment growth
dC_o    = cstY + 100*(log(c/c(-1)) + fiz);

// Eq O2: Observed investment growth
sh60_o    = csts60  + 100*(s60 - s60ss ) + 100*fime;

// Eq O2: Observed investment growth
dC40_o    = cstY + 100*(log(c40/c40(-1)) + fiz);

// Eq O3: Observed investment growth
dC60_o    = cstY + 100*(log(c60/c60(-1)) + fiz);

// Eq O4: Observed output growth
dY_o    = cstY + 100*(log(y/y(-1)) + fiz);

// Eq O5: Observed job filling rate
df_o     = cstdf + 100*(f-f(-1));

// Eq O6: Observed separation rate
ds_o     = cstds + 100*(s-s(-1));

// Eq O7: Observed inflation rate
dP_o    = cstP + 100*(pi-piss);

// Eq O8: Observed wage inflation rate
dW_o    = cstW + 100*(log(w/w(-1)) + fiz + pi-piss);

// Eq O5: Observed job filling rate
f_o     = cstf + 100*(f-fss);

// Eq O6: Observed separation rate
s_o     = csts + 100*(s-sss);


end;
// --------------------------------------------------------------------
// E N D  O F  M O D E L  B L O C K
// --------------------------------------------------------------------


// --------------------------------------------------------------------
// S T E A D Y  S T A T E  B L O C K
// --------------------------------------------------------------------
//
// Step #1 : define local values
//
// --------------------------------------------------------------------
steady_state_model;
muz0       = cstY/100;
fss0       = cstf/100;
sss0       = csts/100;
Rss0       = cstR/100;
piss0      = cstP/100;
s60ss0     = csts60/100;
mu0        = theta/(theta-1);
s0         = sss0;
f0         = fss0;
u0         = 1;
Delta0     = 1;
pk0        = 1;
pstar0     = 1;
r0         = (1+Rss0)/(1+piss0)-1;
pm0        = 1/mu0;
pia0       = (1+piss0)^4-1;
betaF0     = exp(sig*muz0)*(1+piss0)/(1+Rss0);
MF0        = betaF0/exp(sig*muz0);
rho0       = s0/(1-f0);
phi0       = 1 - (1-(1-rho0)*exp((1-sig)*muz0)*betaF0)*kv_y/rho0 - lsh;
rk0        = ( exp(sig*muz0) - betaF0*(1-delta) )/betaF0;
n0         = f0/(s0+f0);
m0         = rho0*n0;
neu0       = s0*n0;
nuu0       = 1-n0-neu0;
tau0       = (1-n0)/(n0/reprat);
isy0       = (phi0*betaF0*(1-(1-delta)/exp(muz0)))/(( exp(sig*muz0) - betaF0*(1-delta) )/exp(muz0))/(1-Omega);
csy0       = 1-(1-Omega)*isy0-kv_y; 
Num0       = ceu_ce*(1-reprat*(1-n0)/n0)-reprat;
Den0       = ceu_ce + (1+r0)*exp(-muz0)*(1-(1-s0)*ceu_ce);
ae_w0      = Num0/Den0;
psi0       = ((ae_w0*((1+r0)*exp(-muz0)-1)+1)*lsh/(csy0*s60ss0)-1)*0.6/(0.4);
psiRA0     = 0.4*psi0 ;
alpo0      = (0.6-Omega)/0.6*(psiRA0) + (Omega/0.6)*(Omega + (psi0)*(1-Omega));
k0         = exp(muz0)*( mu0*rk0/phi0 )^(1/(phi0-1))*(alpo0)*n0/(1-Omega);
y0         = (1-Omega)*k0*rk0/phi0/exp(muz0);
ym0        = mu0*y0;
i0         = (1-(1-delta)/exp(muz0))*k0;
w0         = lsh*y0/((alpo0)*n0);
bu0        = reprat*w0;
q0         = (1-phi0)*y0/((alpo0)*n0);
Kp0        = mu0*pm0*y0/(1-alpha*exp(muz0)*MF0);
Fp0        = y0/(1-alpha*exp(muz0)*MF0);
v0         = m0^(1/(1-chi))/(1-(1-rho0)*n0)^(chi/(1-chi));
kappav0    = kv_y*y0/v0;
bF_bW0     = s0*(ceu_ce)^(-sig) + (1-s0);
betaW0     = betaF0/bF_bW0;
cuu0       = bu0;
ceu0       = ((1-tau0)*w0-(1-s0-exp(muz0)/(1+r0))*bu0)/(1/ceu_ce - (1-s0-exp(muz0)/(1+r0)) );
ce0        = ceu0/ceu_ce;
ae0        = exp(muz0)/(1+r0)*(ceu0-bu0);
Ae0        = exp(-muz0)*(1-s0)*n0*ae0;
aF0        = -Omega/(1-Omega)*Ae0;
cF0        = (y0 - Omega*( n0*ce0 + (1-f0)*(1-n0)*cuu0 + s0*n0*ceu0 ) - kappav0*v0 - (1-Omega)*i0)/(1-Omega);
lamF0      = ( (1-hF/exp(muz0))*cF0 )^(-sig) ;
lame0      = ( (1-hF/exp(muz0))*ce0 )^(-sig) ;
lameu0     = ( (1-hF/exp(muz0))*ceu0 )^(-sig) ;
MW0        = betaW0*exp(-sig*(muz0))*( (1-s0)*lame0 + s0*lameu0 )/lame0;
lambda0    = m0/v0;
c0         = (1-Omega)*cF0 + Omega*(n0*ce0+nuu0*cuu0+neu0*ceu0) ;
c400       = (1-Omega)*cF0;
c600       = Omega*(n0*ce0+nuu0*cuu0+neu0*ceu0);
lamuu0     = ( (1-hF/exp(muz0))*cuu0 )^(-sig) ;
cndreduc10 = 1 - exp(-sig*(muz0))*betaW0*((1-f0)*lamuu0+f0*lame0)*(1+r0)/lameu0;
cndreduc20 = 1 - exp(-sig*(muz0))*betaW0*((1-f0)*lamuu0+f0*lame0)*(1+r0)/lamuu0;
Je0        = (q0-w0)/(1-(1-rho0)*MF0);
cndw0      = w0-bu0;
linv0      = log((1-Omega)*i0 + kappav0*v0);
lcHtM0     = log(c400 + Omega*w0*n0);
// --------------------------------------------------------------------
//
// Step #2 : assign these local values
//
// --------------------------------------------------------------------
r         = r0;
R         = Rss0;
MF        = MF0;
MW        = MW0;
lamF      = lamF0;
lame      = lame0;
lameu     = lameu0;
cF        = cF0;
ce        = ce0;
ceu       = ceu0;
cuu       = cuu0;
aF        = aF0;
ae        = ae0;
Ae        = Ae0;
lambda    = lambda0;
m         = m0;
v         = v0;
s         = s0;
f         = f0;
n         = n0;
neu       = neu0;
nuu       = nuu0;
rho       = rho0;
k         = k0;
i         = i0;
u         = u0;
y         = y0;
ym        = ym0;
rk        = rk0;
pk        = 1;
w         = w0;
q         = q0;
tau       = tau0;
pm        = pm0;
Kp        = Kp0;
Fp        = Fp0;
pstar     = 1;
Delta     = 1;
c         = c0;
c40       = c400;
c60       = c600;
pi        = piss0;
pia       = pia0;
R_o       = cstR;
dC_o      = cstY;
dI_o      = cstY;
dC40_o    = cstY;
dC60_o    = cstY;
s60       = c600/c0;
sh60_o    = 100*s60;
dY_o      = cstY;
df_o      = cstdf;
ds_o      = cstds;
dP_o      = cstP;
dW_o      = cstW;
f_o       = cstf;
s_o       = csts;
cndreduc1 = cndreduc10;
cndreduc2 = cndreduc20;
cndw      = cndw0;
Je        = Je0;
lc        = log(c0);
li        = log(i0);
ly        = log(y0);
lc60      = log(c600);
lc40      = log(c400);
lw        = log(w0);
linv      = linv0;
lcHtM     = lcHtM0;
Ra        = 4*Rss0;
lamuu     = lamuu0;
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
    fi@{name} = 0;
@#endfor
end;
// --------------------------------------------------------------------
// E N D  O F  S T E A D Y  S T A T E  B L O C K
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// WARNING: if you want to check the steady state you can uncomment
// the lines below. Please, re-comment them once you're convinced
// that everything works fine
// --------------------------------------------------------------------
//options_.dynatol.f = 1e-10;
steady;
check;
//return;

// --------------------------------------------------------------------
// S H O C K  B L O C K
// --------------------------------------------------------------------
shocks;
@#for name in [ "c", "w", "i", "p", "R", "z", "s", "a", "me", "m", "t" ]
        var  eps@{name};
        stderr 1;
@#endfor
end;
// --------------------------------------------------------------------
// E N D  O F  S H O C K  B L O C K
// --------------------------------------------------------------------
